@@ -41,11 +41,11 @@
  *                MdcHashSDBM()           - Get hash using sdbm method     *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id$
+/*
  */
 
 /*
-   Copyright (C) 1997-2019 by Erik Nolf
+   Copyright (C) 1997-2026 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -69,13 +69,13 @@
 #include <stdio.h>
 #define __USE_ISOC99 1
 #include <math.h>
-#ifdef HAVE_STDLIB_H
+#ifdef LIBMDC_HAVE_STDLIB_H
 #include <stdlib.h>
 #endif
-#ifdef HAVE_STRING_H
+#ifdef LIBMDC_HAVE_STRING_H
 #include <string.h>
 #endif
-#ifdef HAVE_STRINGS_H
+#ifdef LIBMDC_HAVE_STRINGS_H
 #ifndef _WIN32
 #include <strings.h>
 #endif
@@ -260,10 +260,10 @@ int MdcFixFloat(float *ref)
   float value = *ref;
   int fixed = 0;
 
-#ifdef HAVE_ISNAN
+#ifdef LIBMDC_HAVE_ISNAN
   if (isnan(value)) { value = 0.; fixed = 1; }
 #endif
-#ifdef HAVE_ISINF
+#ifdef LIBMDC_HAVE_ISINF
   if (isinf(value)) { value = 0.; fixed = 1; }
 #endif
 
@@ -277,10 +277,10 @@ int MdcFixDouble(double *ref)
   double value = *ref;
   int fixed = 0;
 
-#ifdef HAVE_ISNAN
+#ifdef LIBMDC_HAVE_ISNAN
   if (isnan(value)) { value = 0.; fixed = 1; }
 #endif
-#ifdef HAVE_ISINF
+#ifdef LIBMDC_HAVE_ISINF
   if (isinf(value)) { value = 0.; fixed = 1; }
 #endif
 
