@@ -17,11 +17,11 @@
  *                MdcGetSpmOpt()           - Get specific SPM options      *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id$
+/*
  */
 
 /*
-   Copyright (C) 1997-2019 by Erik Nolf
+   Copyright (C) 1997-2026 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -44,18 +44,18 @@
 #include "m-depend.h"
 
 #include <stdio.h>
-#ifdef HAVE_STDLIB_H
+#ifdef LIBMDC_HAVE_STDLIB_H
 #include <stdlib.h>
 #endif
-#ifdef HAVE_STRING_H
+#ifdef LIBMDC_HAVE_STRING_H
 #include <string.h>
 #endif
-#ifdef HAVE_STRINGS_H
+#ifdef LIBMDC_HAVE_STRINGS_H
 #ifndef _WIN32
 #include <strings.h>
 #endif
 #endif
-#ifdef HAVE_UNISTD_H
+#ifdef LIBMDC_HAVE_UNISTD_H
 #include <unistd.h>
 #endif
 
@@ -125,7 +125,7 @@ const char *MdcReadANLZ(FILEINFO *fi)
   if (MDC_VERBOSE) MdcPrntMesg("ANLZ Reading <%s> ...",fi->ifname);
 
   /* get endian of the file in MDC_FILE_ENDIAN */
-  i=MdcCheckANLZ(fi); fseek(fp,0,SEEK_SET);
+  i=MdcCheckANLZ(fi); fseeko(fp,(off_t)0,SEEK_SET);
   if (i != MDC_FRMT_ANLZ) {
     if (MDC_FALLBACK_FRMT == MDC_FRMT_ANLZ) {
       /* set host endian to try analyze */
@@ -421,8 +421,8 @@ const char *MdcReadANLZ(FILEINFO *fi)
   if (MDC_ANLZ_SPM == MDC_YES) {
     /* interpret offset value from the header but we keep */
     /* our precautions ... badly initialized headers      */
-    long offsetu = (long)opt->offset;
-    if ((float)offsetu == opt->offset) fseek(fi->ifp,offsetu,SEEK_SET);
+    off_t offseto = (off_t)opt->offset;
+    if ((float)offseto == opt->offset) fseeko(fi->ifp,offseto,SEEK_SET);
   }
 
   if (!MdcGetStructID(fi,number)) {
