@@ -17,11 +17,11 @@
  *                MdcSetPresentMap() - Preserve colormap in colored file   *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id$
+/*
  */
 
 /*
-   Copyright (C) 1997-2019 by Erik Nolf
+   Copyright (C) 1997-2026 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -44,10 +44,13 @@
 #include "m-depend.h"
 
 #include <stdio.h>
-#ifdef HAVE_STRING_H
+#ifdef LIBMDC_HAVE_STDLIB_H
+#include <stdlib.h>
+#endif
+#ifdef LIBMDC_HAVE_STRING_H
 #include <string.h>
 #endif
-#ifdef HAVE_STRINGS_H
+#ifdef LIBMDC_HAVE_STRINGS_H
 #ifndef _WIN32
 #include <strings.h>
 #endif
@@ -55,6 +58,7 @@
 #include "m-defs.h"
 #include "m-global.h"
 #include "m-color.h"
+#include "m-palette.h"
 
 /****************************************************************************
                               D E F I N E S
@@ -79,22 +83,38 @@ struct {int n,r,g,b,dr,dg,db; }
 int  MdcLoadLUT(const char *lutname)
 {
   FILE *fp;
-  int s;
+  int n;
 
   LOADED = MDC_NO;
 
+  /* if a number was given, try to load internal palette */
+  if (strlen(lutname) <= 3) {
+
+    n = atoi(lutname);
+
+    if ((n >= 0) && (n < mdc_max_palette)) {
+
+      memcpy(loaded_map,mdc_palette[n],768);
+
+      LOADED = MDC_YES;
+
+      return(MDC_YES);
+    }
+  }
+
+  /* otherwise open as an external file */
   if ((fp=fopen(lutname,"rb")) == NULL) return(MDC_NO);
 
+  n = fread(mdcbufr,sizeof(char),768,fp); fclose(fp);
+  if (n != 768) return(MDC_NO); /* just skip */
+
   LOADED = MDC_YES;
 
-  /* get red values */
-  for (s=0; s<768; s+=3) loaded_map[s] = (Uint8)fgetc(fp);
-  /* get green values */
-  for (s=1; s<768; s+=3) loaded_map[s] = (Uint8)fgetc(fp);
-  /* get blue values */
-  for (s=2; s<768; s+=3) loaded_map[s] = (Uint8)fgetc(fp);
-
-  fclose(fp);
+  for (n=0; n<256; n++) {
+     loaded_map[n*3+0] = mdcbufr[n+0];     /* red   */
+     loaded_map[n*3+1] = mdcbufr[n+256];   /* green */
+     loaded_map[n*3+2] = mdcbufr[n+512];   /* blue  */
+  }
 
   return(MDC_YES);
 }
