@@ -1,6 +1,6 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * filename: m-debug.c                                                     *
- *                                                                         * 
+ *                                                                         *
  * UTIL C-source: Medical Image Conversion Utility                         *
  *                                                                         *
  * purpose      : print FILEINFO structure                                 *
@@ -11,11 +11,11 @@
  *                MdcDebugPrint()    - Print MDC_MY_DEBUG info             *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-debug.c,v 1.70 2011/12/27 00:46:06 enlf Exp $
+/*
  */
 
 /*
-   Copyright (C) 1997-2012 by Erik Nolf
+   Copyright (C) 1997-2026 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -52,7 +52,7 @@
 ****************************************************************************/
 
 void MdcPrintFI(FILEINFO *fi)
-{ 
+{
   Uint32 i, j;
   int v;
   float f;
@@ -70,7 +70,7 @@ void MdcPrintFI(FILEINFO *fi)
   else MdcPrntScrn("%p\n",fi->ofp);
   MdcPrntScrn("ipath              : %s\n",fi->ipath);
   MdcPrntScrn("opath              : %s\n",fi->opath);
-  if (fi->idir == NULL) 
+  if (fi->idir == NULL)
   MdcPrntScrn("idir               : <null>\n");
   else
   MdcPrntScrn("idir               : %s\n",fi->idir);
@@ -306,7 +306,7 @@ void MdcPrintFI(FILEINFO *fi)
      id = &fi->image[i];
      MdcPrntScrn("\n");
      MdcPrintLine('-',MDC_FULL_LENGTH);
-     MdcPrntScrn("FILEINFO - Image Data #%.3u\n",i+1);  
+     MdcPrntScrn("FILEINFO - Image Data #%.3u\n",i+1);
      MdcPrintLine('-',MDC_FULL_LENGTH);
      MdcPrntScrn("width              : %u\n",id->width);
      MdcPrntScrn("height             : %u\n",id->height);
@@ -327,7 +327,7 @@ void MdcPrintFI(FILEINFO *fi)
      MdcPrntScrn("frame_number       : %u\n",id->frame_number);
      MdcPrntScrn("slice_start        : %+e [ms] = %s\n"
                 ,id->slice_start,MdcGetStrHHMMSS(id->slice_start));
-     f = MdcSingleImageDuration(fi,id->frame_number-1); 
+     f = MdcSingleImageDuration(fi,id->frame_number-1);
      MdcPrntScrn("slice_duration     : %+e [ms] = %s (auto-filled)\n"
                 ,f,MdcGetStrHHMMSS(f));
      MdcPrntScrn("rescaled           : %d ",id->rescaled);
@@ -338,7 +338,7 @@ void MdcPrintFI(FILEINFO *fi)
      MdcPrntScrn("rescaled_slope     : %+e\n",id->rescaled_slope);
      MdcPrntScrn("rescaled_intercept : %+e\n",id->rescaled_intercept);
      MdcPrntScrn("buf                : %p\n",id->buf);
-     MdcPrntScrn("load_location      : %ld\n",id->load_location);
+     MdcPrntScrn("load_location      : %jd\n",(intmax_t)id->load_location);
      MdcPrntScrn("quant_units        : %hd\n",id->quant_units);
      MdcPrntScrn("calibr_units       : %hd\n",id->calibr_units);
      MdcPrntScrn("quant_scale        : %+e\n",id->quant_scale);
@@ -384,7 +384,7 @@ void MdcPrintFI(FILEINFO *fi)
    MdcPrntScrn("\n");
    MdcPrintLine('-',MDC_HALF_LENGTH);
    MdcPrntScrn("FILEINFO - DICOM General Info\n");
-   MdcPrintLine('-',MDC_HALF_LENGTH); 
+   MdcPrintLine('-',MDC_HALF_LENGTH);
 
    MdcPrntScrn("study_date            : %s\n",gn->study_date);
    MdcPrntScrn("study_time            : %s\n",gn->study_time);
@@ -399,7 +399,7 @@ void MdcPrintFI(FILEINFO *fi)
      case M_MR:
          MdcPrintLine('-',MDC_HALF_LENGTH);
          MdcPrntScrn("FILEINFO - DICOM MR Modality Info\n");
-         MdcPrintLine('-',MDC_HALF_LENGTH); 
+         MdcPrintLine('-',MDC_HALF_LENGTH);
          MdcPrntScrn("repetition_time       : %f\n",mr->repetition_time);
          MdcPrntScrn("echo_time             : %g\n",mr->echo_time);
          MdcPrntScrn("inversion_time        : %g\n",mr->inversion_time);
