@@ -7,7 +7,7 @@
  *                                                                         *
  * project      : (X)MedCon by Erik Nolf                                   *
  *                                                                         *
- * Functions    : MdcCheckECAT6()         - Check for ECAT 6.4 format      * 
+ * Functions    : MdcCheckECAT6()         - Check for ECAT 6.4 format      *
  *                MdcReadECAT6()          - Read ECAT 6.4 file             *
  *                MdcWriteECAT6()         - Write ECAT 6.4 file            *
  *                MdcGetSliceLocation()   - Get slice location             *
@@ -24,11 +24,11 @@
  *                - Sakari Alenius   - reading using a matrix list         *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-ecat64.c,v 1.87 2011/12/27 00:46:06 enlf Exp $
+/*
  */
 
 /*
-   Copyright (C) 1997-2012 by Erik Nolf
+   Copyright (C) 1997-2026 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -51,13 +51,13 @@
 #include "m-depend.h"
 
 #include <stdio.h>
-#ifdef HAVE_STDLIB_H
+#ifdef LIBMDC_HAVE_STDLIB_H
 #include <stdlib.h>
 #endif
-#ifdef HAVE_STRING_H
+#ifdef LIBMDC_HAVE_STRING_H
 #include <string.h>
 #endif
-#ifdef HAVE_STRINGS_H
+#ifdef LIBMDC_HAVE_STRINGS_H
 #ifndef _WIN32
 #include <strings.h>
 #endif
@@ -115,7 +115,7 @@ static Int16 MdcEcatSystemTypes[MDC_MAX_ECATSYSTEMTYPES]=
                             F U N C T I O N S
 ****************************************************************************/
 int MdcCheckECAT6(FILEINFO *fi)
-{ 
+{
   Mdc_Main_header mh;
   int i;
 
@@ -173,13 +173,13 @@ const char *MdcReadECAT6(FILEINFO *fi)
   }
 */
 
-  if (MDC_INFO || MDC_INFO_DB) { 
+  if (MDC_INFO || MDC_INFO_DB) {
 
     MdcPrntScrn("Main Header (%d bytes)\n",MH_64_SIZE);
     MdcPrintLine('-',MDC_HALF_LENGTH);
- 
-    MdcPrntScrn("Original Filename        : "); 
-       MdcPrintStr(mh.original_file_name);
+
+    strncpy(mdcbufr,mh.original_file_name,20); mdcbufr[20]='\0';
+    MdcPrntScrn("Original Filename        : "); MdcPrintStr(mdcbufr);
     MdcPrntScrn("Software Version         : %d\n",mh.sw_version);
     MdcPrntScrn("Data Type                : %d ",mh.data_type);
     if ((mh.data_type > -1) && (mh.data_type < 8))
@@ -188,21 +188,23 @@ const char *MdcReadECAT6(FILEINFO *fi)
       MdcPrntScrn("(= Unknown)\n");
     MdcPrntScrn("System Type              : %d\n",mh.system_type);
     MdcPrntScrn("File Type                : %d ",mh.file_type);
-    if ((mh.file_type > -1) && (mh.file_type < 5)) 
+    if ((mh.file_type > -1) && (mh.file_type < 5))
       MdcPrntScrn("(= %s)\n",MdcEcatFileTypes[mh.file_type]);
     else
       MdcPrntScrn("(= Unknown)\n");
-    MdcPrntScrn("Node Id                  : "); MdcPrintStr(mh.node_id);
+    strncpy(mdcbufr,mh.node_id,10); mdcbufr[10]='\0';
+    MdcPrntScrn("Node Id                  : "); MdcPrintStr(mdcbufr);
     MdcPrntScrn("Scan Date - Day          : %d\n",mh.scan_start_day);
     MdcPrntScrn("          - Month        : %d\n",mh.scan_start_month);
     MdcPrntScrn("          - Year         : %d\n",mh.scan_start_year);
     MdcPrntScrn("          - Hour         : %d\n",mh.scan_start_hour);
     MdcPrntScrn("          - Minute       : %d\n",mh.scan_start_minute);
     MdcPrntScrn("          - Second       : %d\n",mh.scan_start_second);
-    MdcPrntScrn("Isotope Code             : "); MdcPrintStr(mh.isotope_code);
+    strncpy(mdcbufr,mh.isotope_code,8); mdcbufr[8]='\0';
+    MdcPrntScrn("Isotope Code             : "); MdcPrintStr(mdcbufr);
     MdcPrntScrn("Isotope Halflife         : %f [sec]\n",mh.isotope_halflife);
-    MdcPrntScrn("Radiopharmaceutical      : "); 
-      MdcPrintStr(mh.radiopharmaceutical);
+    strncpy(mdcbufr,mh.radiopharmaceutical,32); mdcbufr[32]='\0';
+    MdcPrntScrn("Radiopharmaceutical      : "); MdcPrintStr(mdcbufr);
     MdcPrntScrn("Gantry Tilt              : %f [degrees]\n",mh.gantry_tilt);
     MdcPrntScrn("Gantry Rotation          : %f [degrees]\n"
                                                           ,mh.gantry_rotation);
@@ -222,28 +224,32 @@ const char *MdcReadECAT6(FILEINFO *fi)
     if ((mh.calibration_units > -1) && (mh.calibration_units < 12))
       MdcPrntScrn("(= %s)\n"
                     ,MdcEcatQuantificationUnits[mh.calibration_units]);
-    else 
+    else
       MdcPrntScrn("(= Unknown)\n");
     MdcPrntScrn("Compression Code         : %d\n",mh.compression_code);
-    MdcPrntScrn("Study Name               : "); MdcPrintStr(mh.study_name);
-    MdcPrntScrn("Patient Id               : "); MdcPrintStr(mh.patient_id);
-    MdcPrntScrn("Patient Name             : "); MdcPrintStr(mh.patient_name);
-    MdcPrntScrn("Patient Sex              : "); MdcPrintChar(mh.patient_sex);  
+    strncpy(mdcbufr,mh.study_name,12); mdcbufr[12]='\0';
+    MdcPrntScrn("Study Name               : "); MdcPrintStr(mdcbufr);
+    strncpy(mdcbufr,mh.patient_id,16); mdcbufr[16]='\0';
+    MdcPrntScrn("Patient Id               : "); MdcPrintStr(mdcbufr);
+    strncpy(mdcbufr,mh.patient_name,32); mdcbufr[32]='\0';
+    MdcPrntScrn("Patient Name             : "); MdcPrintStr(mdcbufr);
+    MdcPrntScrn("Patient Sex              : "); MdcPrintChar(mh.patient_sex);
     MdcPrntScrn("\n");
-    MdcPrntScrn("Patient Age              : "); MdcPrintStr(mh.patient_age);
-    MdcPrntScrn("Patient Height           : ");
-       MdcPrintStr(mh.patient_height);
-    MdcPrntScrn("Patient Weight           : ");
-       MdcPrintStr(mh.patient_weight);
-    MdcPrntScrn("Patient Dexterity        : "); 
+    strncpy(mdcbufr,mh.patient_age,10); mdcbufr[10]='\0';
+    MdcPrntScrn("Patient Age              : "); MdcPrintStr(mdcbufr);
+    strncpy(mdcbufr,mh.patient_height,10); mdcbufr[10]='\0';
+    MdcPrntScrn("Patient Height           : "); MdcPrintStr(mdcbufr);
+    strncpy(mdcbufr,mh.patient_weight,10); mdcbufr[10]='\0';
+    MdcPrntScrn("Patient Weight           : "); MdcPrintStr(mdcbufr);
+    MdcPrntScrn("Patient Dexterity        : ");
        MdcPrintChar(mh.patient_dexterity);
     MdcPrntScrn("\n");
-    MdcPrntScrn("Physician Name           : ");
-       MdcPrintStr(mh.physician_name);
-    MdcPrntScrn("Operator Name            : ");
-       MdcPrintStr(mh.operator_name);
-    MdcPrntScrn("Study Description        : ");
-       MdcPrintStr(mh.study_description);
+    strncpy(mdcbufr,mh.physician_name,32); mdcbufr[32]='\0';
+    MdcPrntScrn("Physician Name           : "); MdcPrintStr(mdcbufr);
+    strncpy(mdcbufr,mh.operator_name,32); mdcbufr[32]='\0';
+    MdcPrntScrn("Operator Name            : "); MdcPrintStr(mdcbufr);
+    strncpy(mdcbufr,mh.study_description,32); mdcbufr[32]='\0';
+    MdcPrntScrn("Study Description        : "); MdcPrintStr(mdcbufr);
     MdcPrntScrn("Acquisition Type         : %d ",mh.acquisition_type);
     if ((mh.acquisition_type > -1) && (mh.acquisition_type <= 9))
       MdcPrntScrn("(= %s)\n",MdcEcatAcquisitionTypes[mh.acquisition_type]);
@@ -251,7 +257,8 @@ const char *MdcReadECAT6(FILEINFO *fi)
       MdcPrntScrn("(= Unknown)\n");
     MdcPrntScrn("Bed Type                 : %d\n",mh.bed_type);
     MdcPrntScrn("Septa Type               : %d\n",mh.septa_type);
-    MdcPrntScrn("Facility Name            : "); MdcPrintStr(mh.facility_name);
+    strncpy(mdcbufr,mh.facility_name,20); mdcbufr[20]='\0';
+    MdcPrntScrn("Facility Name            : "); MdcPrintStr(mdcbufr);
     MdcPrntScrn("Number of Planes         : %d\n",mh.num_planes);
     MdcPrntScrn("Number of Frames         : %d\n",mh.num_frames);
     MdcPrntScrn("Number of Gates          : %d\n",mh.num_gates);
@@ -261,22 +268,22 @@ const char *MdcReadECAT6(FILEINFO *fi)
     MdcPrntScrn("Bed Offset[%02d]           : %f [cm]\n",i+1
                                                            ,mh.bed_offset[i]);
     MdcPrntScrn("Plane Separation         : %f [cm]\n",mh.plane_separation);
-    MdcPrntScrn("Lower Scatter Treshold   : %d [KeV]\n",mh.lwr_sctr_thres);
-    MdcPrntScrn("Lower True Treshold      : %d [KeV]\n",mh.lwr_true_thres);
-    MdcPrntScrn("Upper True Treshold      : %d [KeV]\n",mh.upr_true_thres);
+    MdcPrntScrn("Lower Scatter Threshold  : %d [KeV]\n",mh.lwr_sctr_thres);
+    MdcPrntScrn("Lower True Threshold     : %d [KeV]\n",mh.lwr_true_thres);
+    MdcPrntScrn("Upper True Threshold     : %d [KeV]\n",mh.upr_true_thres);
     MdcPrntScrn("Collimator               : %6.0f\n",mh.collimator);
-    MdcPrntScrn("User Process Code        : ");
-       MdcPrintStr(mh.user_process_code);
+    strncpy(mdcbufr,mh.user_process_code,10); mdcbufr[10]='\0';
+    MdcPrntScrn("User Process Code        : "); MdcPrintStr(mdcbufr);
     MdcPrntScrn("Acquisition Mode         : %d\n",mh.acquisition_mode);
 
   }
 
   if (MDC_INFO_DB) return(NULL); /* just needed db info */
 
-  if ((mh.file_type!=MDC_ECAT6_SCAN_FILE)  && 
+  if ((mh.file_type!=MDC_ECAT6_SCAN_FILE)  &&
       (mh.file_type!=MDC_ECAT6_IMAGE_FILE) &&
-      (mh.file_type!=MDC_ECAT6_ATTN_FILE)  && 
-      (mh.file_type!=MDC_ECAT6_NORM_FILE) ) 
+      (mh.file_type!=MDC_ECAT6_ATTN_FILE)  &&
+      (mh.file_type!=MDC_ECAT6_NORM_FILE) )
     return("ECAT6 Unsupported file type");
 
   if (mh.num_frames  <= 0 ) mh.num_frames  = 1;
@@ -308,7 +315,7 @@ const char *MdcReadECAT6(FILEINFO *fi)
 
     axial_width = mh.plane_separation * (float)fi->dim[3];
     if ((axial_width - bed_offset) >= 1.0) {
-      MdcPrntWarn("ECAT6 Bed overlaps unsupported"); 
+      MdcPrntWarn("ECAT6 Bed overlaps unsupported");
     }
   }
 
@@ -316,23 +323,23 @@ const char *MdcReadECAT6(FILEINFO *fi)
 
   if (number == 0) return("ECAT6 No valid images specified");
 
-  /* fill in orientation information */ 
+  /* fill in orientation information */
   fi->pat_slice_orient = MDC_SUPINE_HEADFIRST_TRANSAXIAL; /* default! */
   str = MdcGetStrPatPos(fi->pat_slice_orient);
   MdcStringCopy(fi->pat_pos,str,strlen(str));
 
   if ( (strncmp(mh.user_process_code,"COR",10)==0) ||
        (strncmp(mh.user_process_code,"SAG",10)==0)) {
-    /* CORONAL SLICES  or SAGITTAL SLICES 
+    /* CORONAL SLICES  or SAGITTAL SLICES
        The images Ecat 6.4 software writes are useless:
        128x128 images with the small coronal/sagittal slice in it ...
        This means their pixel_xsize & pixel_ysize doesn't quite
-       fit the real world dimensions any more !! 
-       Therefore we don't even try to attempt writing the proper 
+       fit the real world dimensions any more !!
+       Therefore we don't even try to attempt writing the proper
        orientation information.
      */
   }else{
-    /* "TRA" or nothing 
+    /* "TRA" or nothing
        TRANSAXIAL SLICES (Transverse)
        Writing the proper orientation information
        See man-page `m-acr.4' for more info (!)
@@ -354,30 +361,30 @@ const char *MdcReadECAT6(FILEINFO *fi)
   fi->study_time_minute= mh.scan_start_minute;
   fi->study_time_second= mh.scan_start_second;
 
-  if ((mh.file_type==MDC_ECAT6_SCAN_FILE) || 
+  if ((mh.file_type==MDC_ECAT6_SCAN_FILE) ||
       (mh.file_type==MDC_ECAT6_IMAGE_FILE)) {
     switch (mh.acquisition_type) {
-      case MDC_ECAT6_ACQTYPE_UNKNOWN : 
+      case MDC_ECAT6_ACQTYPE_UNKNOWN :
           fi->acquisition_type = MDC_ACQUISITION_UNKNOWN; break;
-      case MDC_ECAT6_ACQTYPE_BLANK : 
+      case MDC_ECAT6_ACQTYPE_BLANK :
           fi->acquisition_type = MDC_ACQUISITION_UNKNOWN; break;
-      case MDC_ECAT6_ACQTYPE_TRANSMISSION : 
+      case MDC_ECAT6_ACQTYPE_TRANSMISSION :
           fi->acquisition_type = MDC_ACQUISITION_TOMO;    break;
-      case MDC_ECAT6_ACQTYPE_STATIC_EMISSION : 
+      case MDC_ECAT6_ACQTYPE_STATIC_EMISSION :
           fi->acquisition_type = MDC_ACQUISITION_TOMO;    break;
-      case MDC_ECAT6_ACQTYPE_DYNAMIC_EMISSION : 
+      case MDC_ECAT6_ACQTYPE_DYNAMIC_EMISSION :
           fi->acquisition_type = MDC_ACQUISITION_DYNAMIC; break;
-      case MDC_ECAT6_ACQTYPE_GATED_EMISSION : 
+      case MDC_ECAT6_ACQTYPE_GATED_EMISSION :
           fi->acquisition_type = MDC_ACQUISITION_GSPECT;  break;
-      case MDC_ECAT6_ACQTYPE_TRANSMISSION_RECT : 
+      case MDC_ECAT6_ACQTYPE_TRANSMISSION_RECT :
           fi->acquisition_type = MDC_ACQUISITION_UNKNOWN; break;
-      case MDC_ECAT6_ACQTYPE_EMISSION_RECT : 
+      case MDC_ECAT6_ACQTYPE_EMISSION_RECT :
           fi->acquisition_type = MDC_ACQUISITION_UNKNOWN; break;
       case MDC_ECAT6_ACQTYPE_WHOLE_BODY_TRANSM :
           fi->acquisition_type = MDC_ACQUISITION_UNKNOWN; break;
       case MDC_ECAT6_ACQTYPE_WHOLE_BODY_STATIC :
           fi->acquisition_type = MDC_ACQUISITION_TOMO;    break;
-      default: 
+      default:
           fi->acquisition_type = MDC_ACQUISITION_UNKNOWN;
     }
   }else{
@@ -434,11 +441,11 @@ const char *MdcReadECAT6(FILEINFO *fi)
 
       case MDC_ANATOMICAL: /* anatomical */
           bed = fi->dim[6]; /* one based */
-          if (fi->dim[4] > 1) { 
+          if (fi->dim[4] > 1) {
             mdc_plane_sort(matrix_list, num_matrices);
           }else{
             mdc_anatomical_sort(matrix_list, num_matrices, &mh, bed);
-          } 
+          }
           break;
       case MDC_BYFRAME   : /* by frame   */
           mdc_matnum_sort(matrix_list, num_matrices);
@@ -489,7 +496,7 @@ const char *MdcReadECAT6(FILEINFO *fi)
         switch (ssh.smoothing) {
           case 0: MdcPrntScrn("(= Not Smoothed)\n"); break;
           case 1: MdcPrntScrn("(= 9x9 Smoothing)\n"); break;
-         default: MdcPrntScrn("(= Unknown)\n"); 
+         default: MdcPrntScrn("(= Unknown)\n");
         }
         MdcPrntScrn("Processing Code     : %d\n",ssh.processing_code);
         MdcPrntScrn("Sample Distance     : %f [cm]\n",ssh.sample_distance);
@@ -506,7 +513,7 @@ const char *MdcReadECAT6(FILEINFO *fi)
         MdcPrntScrn("Total Multiples     : %d\n",ssh.multiples);
         MdcPrntScrn("Total Net Trues     : %d (Prompts - Random)\n"
                                       ,ssh.net_trues);
-        for (i=0; i<16; i++) 
+        for (i=0; i<16; i++)
         MdcPrntScrn("Corrected   Singles [%2d] : %f\n",i+1
                                                          ,ssh.cor_singles[i]);
         for (i=0; i<16; i++)
@@ -527,7 +534,7 @@ const char *MdcReadECAT6(FILEINFO *fi)
         for (i=0; i<8; i++) MdcPrntScrn("Phy_Planes [%d]          : %d\n",i+1
                                                          ,ssh.phy_planes[i]);
        }
- 
+
        /* fill in DYNAMIC_DATA struct */
        if ((dd != NULL) && (plane == (fi->dim[3]/2))) {
          /* take values from a plane halfway */
@@ -549,7 +556,7 @@ const char *MdcReadECAT6(FILEINFO *fi)
        id->quant_scale = ssh.scale_factor;
 
        id->pixel_xsize = id->pixel_ysize = ssh.sample_distance * 10.;/* mm */
-       data_type = ssh.data_type; 
+       data_type = ssh.data_type;
        switch( data_type ) {
          case  BYTE_TYPE:  id->bits = 8; id->type = BIT8_U; break;
          case  M68K_I2  :
@@ -569,7 +576,7 @@ const char *MdcReadECAT6(FILEINFO *fi)
 
        error = mdc_mat_read_image_subheader(fp, startblk-1, &ish);
        if (error) return("ECAT6 Bad read image subheader");
-       if (MDC_INFO) { 
+       if (MDC_INFO) {
         MdcPrintLine('-',MDC_FULL_LENGTH);
         MdcPrntScrn("IMAGE SUBHEADER %05d:  ",img+1);
         MdcPrntScrn("Frame: %d  Plane: %d  Gate: %d  Data: %d  Bed: %d\n"
@@ -598,9 +605,9 @@ const char *MdcReadECAT6(FILEINFO *fi)
         MdcPrntScrn("Recon Start Hour   : %d\n",ish.recon_start_hour);
         MdcPrntScrn("Recon Start Minute : %d\n",ish.recon_start_minute);
         MdcPrntScrn("Recon Start Second : %d\n",ish.recon_start_sec);
-        MdcPrntScrn("Gate Duration      : %d [ms]\n",ish.gate_duration); 
+        MdcPrntScrn("Gate Duration      : %d [ms]\n",ish.gate_duration);
         MdcPrntScrn("Filter code        : %d ",ish.filter_code);
-        ish.filter_code = abs(ish.filter_code); 
+        ish.filter_code = abs(ish.filter_code);
         if ((ish.filter_code > -1) && (ish.filter_code < 7))
           MdcPrntScrn("(= %s)\n",MdcEcatFilterTypes[ish.filter_code]);
         else
@@ -642,7 +649,8 @@ const char *MdcReadECAT6(FILEINFO *fi)
                                              ,ish.filter_params[4]);
         MdcPrntScrn("Filter Params - Scatter Comp 2   : %f\n"
                                              ,ish.filter_params[5]);
-        MdcPrntScrn("Annotation : "); MdcPrintStr(ish.annotation);
+        strncpy(mdcbufr,ish.annotation,40); mdcbufr[40]='\0';
+        MdcPrntScrn("Annotation : "); MdcPrintStr(mdcbufr);
 
        }
 
@@ -675,7 +683,7 @@ const char *MdcReadECAT6(FILEINFO *fi)
      /*  case  SUN_I2   : */
          case  VAX_I2   :  id->bits =16; id->type = BIT16_S; break;
          case  M68K_I4  :
-     /*  case  SUN_I4   : */ 
+     /*  case  SUN_I4   : */
          case  VAX_I4   :  id->bits =32; id->type = BIT32_S; break;
          case  IEEE_R4  :
      /*  case  SUN_R4   : */
@@ -686,13 +694,13 @@ const char *MdcReadECAT6(FILEINFO *fi)
 
        if ( (strncmp(mh.user_process_code,"COR",10)==0) ||
             (strncmp(mh.user_process_code,"SAG",10)==0)) {
-         /* CORONAL SLICES  or SAGITTAL SLICES 
+         /* CORONAL SLICES  or SAGITTAL SLICES
             The images Ecat 6.4 software writes are useless:
             128x128 images with the small coronal/sagittal slice in it ...
             This means their pixel_xsize & pixel_ysize doesn't quite
-            fit the real world dimensions any more !! 
-            Therefore we don't even try to attempt writing the proper 
-            Acr/Nema variables ... 
+            fit the real world dimensions any more !!
+            Therefore we don't even try to attempt writing the proper
+            Acr/Nema variables ...
           */
        }else{ /* "TRA" or nothing */
          /* TRANSAXIAL SLICES (Transverse)             */
@@ -709,7 +717,7 @@ const char *MdcReadECAT6(FILEINFO *fi)
 
          MdcFillImgPos(fi,img,(Uint32)(plane-1),slice_position);
          MdcFillImgOrient(fi,img);
-         
+
        }
 
        break;
@@ -749,9 +757,9 @@ const char *MdcReadECAT6(FILEINFO *fi)
                                                 ,ash.tilt_angle);
         MdcPrntScrn("Mu-Absorption Coefficient     : %f [1/cm]\n"
                                                 ,ash.attenuation_coeff);
-        MdcPrntScrn("Sample Distance               : %f [cm]\n" 
+        MdcPrntScrn("Sample Distance               : %f [cm]\n"
                                                 ,ash.sample_distance);
-       } 
+       }
 
        /* fill in IMG_DATA struct */
        id = &fi->image[img];
@@ -842,7 +850,7 @@ const char *MdcReadECAT6(FILEINFO *fi)
     bytes = id->width*id->height*MdcType2Bytes(id->type);
     bytes = MdcMatrixBlocks(bytes);
 
-    id->buf = MdcGetImgBuffer(bytes);   
+    id->buf = MdcGetImgBuffer(bytes);
     if (id->buf == NULL) return("ECAT6 Bad malloc image buffer");
 
     error = mdc_mat_read_matrix_data(fp,startblk,endblk,(Int16 *)id->buf);
@@ -854,7 +862,7 @@ const char *MdcReadECAT6(FILEINFO *fi)
     }
 
     if (fi->truncated) break;
-      
+
     img+=1;
   }
 
@@ -887,7 +895,7 @@ const char *MdcReadECAT6(FILEINFO *fi)
     fi->reconstructed = MDC_YES;
     if (ish.decay_corr_fctr > 1.0 ) fi->decay_corrected = MDC_YES;
 
-    MdcStringCopy(fi->recon_method,ish.annotation,strlen(ish.annotation));
+    MdcStringCopy(fi->recon_method,ish.annotation,strnlen(ish.annotation,40));
     if (strcmp(fi->recon_method,MDC_ECAT6_RECON_METHOD)  == 0 ) {
       strcpy(fi->recon_method,"Filtered Backprojection");
     }
@@ -926,7 +934,7 @@ float MdcGetSliceLocation(FILEINFO *fi, Int32 img)
    switch (orient) {
      case MDC_TRANSAXIAL: /* z-coord */
         locat = fi->image[img].image_pos_pat[2];
-        break; 
+        break;
      case MDC_SAGITTAL  : /* x-coord */
         locat = fi->image[img].image_pos_pat[0];
         break;
@@ -945,7 +953,7 @@ int MdcGetFilterCode(char *string)
 {
   int i = 0;
 
-  for (i=0; i<MDC_MAX_ECATFLTRTYPES; i++) 
+  for (i=0; i<MDC_MAX_ECATFLTRTYPES; i++)
      if (strstr(string,MdcEcatFilterTypes[i]) != NULL) break;
 
   return(i);
@@ -960,16 +968,16 @@ void MdcFillMainHeader(FILEINFO *fi, Mdc_Main_header *mh)
   /* memset(mh,0,MH_64_SIZE); */
   memset(mh,0,sizeof(Mdc_Main_header));
 
-  sprintf(mh->original_file_name,"%.19s",fi->ofname);
+  strncpy(mh->original_file_name,fi->ofname,20);
   mh->sw_version = 6;
   mh->system_type= 951;
   mh->file_type  = 2;
 
   mh->data_type = 2;     /* ECAT 6 only reads VAX Int16 */
 
-  sprintf(mh->isotope_code,"%.8s",fi->isotope_code);
+  strncpy(mh->isotope_code,fi->isotope_code,8);
   mh->isotope_halflife = fi->isotope_halflife;
-  sprintf(mh->radiopharmaceutical,"%.31s",fi->radiopharma);
+  strncpy(mh->radiopharmaceutical,fi->radiopharma,32);
   mh->calibration_units = fi->image[0].calibr_units;
   if (fi->pixdim[0] >= 3.) /* only valid for TRANSVERSE slices */
   mh->axial_fov = ((float)fi->dim[3] + 1.) * fi->pixdim[3] / 10.;
@@ -980,42 +988,44 @@ void MdcFillMainHeader(FILEINFO *fi, Mdc_Main_header *mh)
   mh->scan_start_minute= fi->study_time_minute;
   mh->scan_start_second= fi->study_time_second;
   mh->plane_separation = fi->image[0].slice_spacing/10.; /* in cm */
-  sprintf(mh->study_name,"%.11s",fi->study_id);
+  strncpy(mh->study_name,fi->study_id,12);
   mh->gantry_tilt = fi->gantry_tilt;
-  sprintf(mh->patient_id,"%.15s",fi->patient_id);
+  strncpy(mh->patient_id,fi->patient_id,16);
   if (fi->patient_height == 0.) {
     mh->patient_height[0] = '\0';
   }else{
-    sprintf(mh->patient_height,"%.2f",fi->patient_height);
+    sprintf(mdcbufr,"%.2f",fi->patient_height);
+    strncpy(mh->patient_height,mdcbufr,10);
   }
   if (fi->patient_weight == 0.) {
     mh->patient_weight[0] = '\0';
-  }else{ 
-    sprintf(mh->patient_weight,"%.2f",fi->patient_weight);
+  }else{
+    sprintf(mdcbufr,"%.2f",fi->patient_weight);
+    strncpy(mh->patient_weight,mdcbufr,10);
   }
-  sprintf(mh->patient_name,"%.31s",fi->patient_name);
+  strncpy(mh->patient_name,fi->patient_name,32);
   mh->patient_sex = fi->patient_sex[0];
-  sprintf(mh->operator_name,"%.31s",fi->operator_name);
-  sprintf(mh->study_description,"%.31s",fi->study_descr);
+  strncpy(mh->operator_name,fi->operator_name,32);
+  strncpy(mh->study_description,fi->study_descr,32);
   switch (fi->acquisition_type ) {
-    case MDC_ACQUISITION_STATIC : 
+    case MDC_ACQUISITION_STATIC :
         mh->acquisition_type = MDC_ECAT6_ACQTYPE_STATIC_EMISSION;  break;
-    case MDC_ACQUISITION_TOMO   :   
+    case MDC_ACQUISITION_TOMO   :
         mh->acquisition_type = MDC_ECAT6_ACQTYPE_STATIC_EMISSION;  break;
-    case MDC_ACQUISITION_DYNAMIC:   
+    case MDC_ACQUISITION_DYNAMIC:
         mh->acquisition_type = MDC_ECAT6_ACQTYPE_DYNAMIC_EMISSION; break;
     case MDC_ACQUISITION_GSPECT :
         mh->acquisition_type = MDC_ECAT6_ACQTYPE_GATED_EMISSION;   break;
-    default                     : 
+    default                     :
         mh->acquisition_type = MDC_ECAT6_ACQTYPE_UNKNOWN;
 
   }
-  sprintf(mh->facility_name,"%.19s",fi->institution);
-  sprintf(mh->user_process_code,"%.10s",MDC_PRGR);
+  strncpy(mh->facility_name,fi->institution,20);
+  strncpy(mh->user_process_code,MDC_PRGR,10);
 
   mh->num_planes = mh->num_frames = mh->num_gates = 1;
   mh->num_bed_pos = 1;
- 
+
   for ( i=3; i<=fi->dim[0]; i++) {
      switch (i) {
        case 3: mh->num_planes  = fi->dim[i];     break;
@@ -1034,13 +1044,13 @@ void MdcFillMainHeader(FILEINFO *fi, Mdc_Main_header *mh)
     mh->init_bed_position = fi->beddata[0].hoffset / 10.; /* cm */
     mh->bed_elevation     = fi->beddata[0].voffset / 10.; /* cm */
 
-    for (i=1; i<fi->bednr; i++) { 
-       if ( i==16 ) { 
+    for (i=1; i<fi->bednr; i++) {
+       if ( i==16 ) {
          MdcPrntWarn("ECAT6 Unsupported number of bed positions");
          break;
        }
        mh->bed_offset[i-1]  = fi->beddata[i].hoffset - fi->beddata[0].hoffset;
-       mh->bed_offset[i-1] /= 10.; /* cm */ 
+       mh->bed_offset[i-1] /= 10.; /* cm */
     }
   }else{
     /* guess bad offsets, assume adjacent bed positions */
@@ -1097,15 +1107,15 @@ void MdcFillImageSubHeader(FILEINFO *fi,Mdc_Image_subheader *ish
     ish->dimension_1 = id->width;
     ish->dimension_2 = id->height;
   }
-  ish->recon_scale = id->recon_scale; 
- 
+  ish->recon_scale = id->recon_scale;
+
   if (ish->data_type == 1 || ish->data_type == 2) {
     if (id->rescaled) {
       ish->image_min = (Int16) id->rescaled_min;
       ish->image_max = (Int16) id->rescaled_max;
     }else{
       ish->image_min = (Int16) id->min;
-      ish->image_max = (Int16) id->max; 
+      ish->image_max = (Int16) id->max;
     }
   }else{ /* data types too big for an Int16 */
     ish->image_min   = 0;
@@ -1130,15 +1140,15 @@ void MdcFillImageSubHeader(FILEINFO *fi,Mdc_Image_subheader *ish
   if (id->rescaled) {
     ish->quant_scale = id->rescaled_fctr;
     ish->ecat_calibration_fctr = 1.;
-  }else{  
+  }else{
     ish->quant_scale = id->quant_scale;
     ish->ecat_calibration_fctr = id->calibr_fctr;
   }
 
   if (strcmp(fi->recon_method,"Filtered Backprojection") == 0 ) {
-    sprintf(ish->annotation,"%.40s",MDC_ECAT6_RECON_METHOD);
-  }else{ 
-    sprintf(ish->annotation,"%.40s",fi->recon_method);
+    strncpy(ish->annotation,MDC_ECAT6_RECON_METHOD,40);
+  }else{
+    strncpy(ish->annotation,fi->recon_method,40);
   }
 }
 
@@ -1147,12 +1157,12 @@ static void MdcResetSizes(FILEINFO *fi)
   fi->mwidth = saved_mwidth;
   fi->mheight= saved_mheight;
 }
- 
+
 const char *MdcWriteECAT6(FILEINFO *fi)
 {
   IMG_DATA *id;
   Mdc_Main_header mh;
-  Mdc_Image_subheader ish; 
+  Mdc_Image_subheader ish;
   Uint8 *buf, *maxbuf;
   Uint16 type, FREE;
   Int32 matnum, data=0, bed, gate, frame, plane, img=0;
@@ -1183,7 +1193,7 @@ const char *MdcWriteECAT6(FILEINFO *fi)
     if (MDC_FORCE_INT != BIT16_S) {
       MdcPrntWarn("ECAT6 Only Int16 pixels supported");
     }
-  } 
+  }
 
   /* check some integrities */
 
@@ -1251,7 +1261,7 @@ const char *MdcWriteECAT6(FILEINFO *fi)
      }
 
      matnum = mdc_mat_numcod(frame,plane,gate,data,bed);
-     MdcFillImageSubHeader(fi,&ish,type,img,matnum,NEWSIZE); 
+     MdcFillImageSubHeader(fi,&ish,type,img,matnum,NEWSIZE);
 
      if (fi->diff_size || NEWSIZE) {
        size = fi->mwidth * fi->mheight * MdcType2Bytes(type);
@@ -1262,7 +1272,7 @@ const char *MdcWriteECAT6(FILEINFO *fi)
          return("ECAT6 Bad malloc maxbuf");
        }
 
-       if (FREE) MdcFree(buf); 
+       if (FREE) MdcFree(buf);
 
        FREE=MDC_YES;
 
@@ -1270,8 +1280,8 @@ const char *MdcWriteECAT6(FILEINFO *fi)
         size = id->width * id->height * MdcType2Bytes(type);
         maxbuf = buf;
      }
- 
-     matnum = mdc_mat_numcod(frame,plane,gate,data,bed);  
+
+     matnum = mdc_mat_numcod(frame,plane,gate,data,bed);
      if (mdc_mat_write_image(fi->ofp,matnum,&ish,(Uint16 *)maxbuf,(Int32)size))
      {
        MdcResetSizes(fi);
@@ -1298,8 +1308,8 @@ void MdcPrintEcatInfoDB(Mdc_Main_header *mh)
 
   Uint32 i, patient_strlen, study_strlen;
 
-  patient_strlen = strlen(mh->patient_name);
-  study_strlen   = strlen(mh->study_name);
+  patient_strlen = strnlen(mh->patient_name,32);
+  study_strlen   = strnlen(mh->study_name,12);
 
   /* remove # from strings, because it is used as field separator! */
   for (i=0; i<patient_strlen; i++) {
@@ -1312,7 +1322,7 @@ void MdcPrintEcatInfoDB(Mdc_Main_header *mh)
   if (study_strlen != 6) {
     MdcPrntScrn("%s",Unknown);
   }else{
-    MdcPrntScrn("%s",mh->study_name);
+    MdcPrntScrn("%.12s",mh->study_name);
   }
   MdcPrntScrn("# ");
 
@@ -1320,7 +1330,7 @@ void MdcPrintEcatInfoDB(Mdc_Main_header *mh)
   if (patient_strlen == 0) {
     MdcPrntScrn("%-35s",Unknown);
   }else{
-    MdcPrntScrn("%-35s",mh->patient_name);
+    MdcPrntScrn("%-35.32s",mh->patient_name);
   }
 
   MdcPrntScrn("#");
