@@ -17,11 +17,11 @@
  *                MdcWriteECAT7()          - Write ECAT7 file              *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-ecat72.c,v 1.72 2011/12/27 00:46:06 enlf Exp $
+/*
  */
 
 /*
-   Copyright (C) 1997-2012 by Erik Nolf
+   Copyright (C) 1997-2026 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -46,13 +46,13 @@
 #include <stdio.h>
 #define __USE_POSIX 1
 #include <time.h>
-#ifdef HAVE_STDLIB_H
+#ifdef LIBMDC_HAVE_STDLIB_H
 #include <stdlib.h>
 #endif
-#ifdef HAVE_STRING_H
+#ifdef LIBMDC_HAVE_STRING_H
 #include <string.h>
 #endif
-#ifdef HAVE_STRINGS_H
+#ifdef LIBMDC_HAVE_STRINGS_H
 #ifndef _WIN32
 #include <strings.h>
 #endif
@@ -102,6 +102,7 @@ int MdcCheckECAT7(FILEINFO *fi)
 void MdcEcatPrintMainHdr(Mdc_Main_header7 *mh)
 {
   int i;
+  time_t my_time;
 
   MdcPrintLine('-',MDC_HALF_LENGTH);
   MdcPrntScrn("ECAT7 Main Header (%d bytes)\n",MH_72_SIZE);
@@ -120,8 +121,8 @@ void MdcEcatPrintMainHdr(Mdc_Main_header7 *mh)
     MdcPrntScrn("(= Unknown)\n");
   MdcGetSafeString(mdcbufr,mh->serial_number,10,10);
   MdcPrntScrn("serial_number            : %s\n",mdcbufr);
-  MdcPrntScrn("scan_start_time          : %s\n"
-                                       ,ctime((time_t *)&mh->scan_start_time));
+  my_time = (time_t)mh->scan_start_time;
+  MdcPrntScrn("scan_start_time          : %s\n",ctime(&my_time));
   MdcGetSafeString(mdcbufr,mh->isotope_name,8,8);
   MdcPrntScrn("isotope_name             : %s\n",mdcbufr);
   MdcPrntScrn("isotope_halflife         : %f [sec]\n",mh->isotope_halflife);
@@ -158,8 +159,8 @@ void MdcEcatPrintMainHdr(Mdc_Main_header7 *mh)
   MdcPrntScrn("patient_age              : %f\n",mh->patient_age);
   MdcPrntScrn("patient_height           : %f\n",mh->patient_height);
   MdcPrntScrn("patient_weight           : %f\n",mh->patient_weight);
-  MdcPrntScrn("patient_birth_date       : %s\n"
-                                    ,ctime((time_t *)&mh->patient_birth_date));
+  my_time = (time_t)mh->patient_birth_date;
+  MdcPrntScrn("patient_birth_date       : %s\n",ctime(&my_time));
   MdcGetSafeString(mdcbufr,mh->physician_name,32,32);
   MdcPrntScrn("physician_name           : %s\n",mdcbufr);
   MdcGetSafeString(mdcbufr,mh->operator_name,32,32);
@@ -175,7 +176,7 @@ void MdcEcatPrintMainHdr(Mdc_Main_header7 *mh)
   MdcPrntScrn("num_gates                : %hd\n",mh->num_gates);
   MdcPrntScrn("num_bed_pos              : %hd\n",mh->num_bed_pos);
   MdcPrntScrn("init_bed_position        : %f\n",mh->init_bed_position);
-    for (i=0; i<15; i++) 
+    for (i=0; i<15; i++)
   MdcPrntScrn("bed_position[%2d]         : %f\n",i,mh->bed_position[i]);
   MdcPrntScrn("plane_separation         : %f [cm]\n",mh->plane_separation);
   MdcPrntScrn("lwr_sctr_thres           : %hd [Kev]\n",mh->lwr_sctr_thres);
@@ -186,14 +187,14 @@ void MdcEcatPrintMainHdr(Mdc_Main_header7 *mh)
   MdcPrntScrn("acquisition_mode         : %hd\n",mh->acquisition_mode);
   MdcPrntScrn("bin_size                 : %f [cm]\n",mh->bin_size);
   MdcPrntScrn("branching_fraction       : %f\n",mh->branching_fraction);
-  MdcPrntScrn("dose_start_time          : %s\n"
-                                       ,ctime((time_t *)&mh->dose_start_time));
+  my_time = (time_t)mh->dose_start_time;
+  MdcPrntScrn("dose_start_time          : %s\n",ctime(&my_time));
   MdcPrntScrn("dosage                   : %e [mCi]\n",mh->dosage);
   MdcPrntScrn("well_counter_corr_factor : %f\n",mh->well_counter_corr_factor);
   MdcGetSafeString(mdcbufr,mh->data_units,32,32);
   MdcPrntScrn("data_units               : %s\n",mdcbufr);
   MdcPrntScrn("septa_state              : %hd\n",mh->septa_state);
-    for (i=0; i<6; i++) 
+    for (i=0; i<6; i++)
   MdcPrntScrn("fill_cti[%d]              : %hd\n",i,mh->fill_cti[i]);
 
 }
@@ -265,7 +266,7 @@ void MdcEcatPrintImgSubHdr(Mdc_Image_subheader7 *ish, int nr)
   MdcPrntScrn("recon_type               : %hd\n",ish->recon_type);
   MdcPrntScrn("recon_views              : %hd\n",ish->recon_views);
   MdcPrntScrn("fill_cti[87]             : <not printed>\n");
-  MdcPrntScrn("fill_user[48]            : <not printed>\n"); 
+  MdcPrntScrn("fill_user[48]            : <not printed>\n");
 
 }
 
@@ -335,7 +336,7 @@ void MdcEcatPrintScanSubHdr(Mdc_Scan_subheader7 *ssh)
   MdcPrntScrn("delayed                  : %d\n",ssh->delayed);
   MdcPrntScrn("multiples                : %d\n",ssh->multiples);
   MdcPrntScrn("net_trues                : %d\n",ssh->net_trues);
-  MdcPrntScrn("cor_singles[16]          : <not printed>\n"); 
+  MdcPrntScrn("cor_singles[16]          : <not printed>\n");
   MdcPrntScrn("uncor_singles[16]        : <not printed>\n");
   MdcPrntScrn("tot_avg_cor              : %g\n",ssh->tot_avg_cor);
   MdcPrntScrn("tot_avg_uncor            : %g\n",ssh->tot_avg_uncor);
@@ -376,10 +377,11 @@ void MdcEcatPrintNormSubHdr(Mdc_Norm_subheader7 *nsh)
 const char *MdcReadECAT7(FILEINFO *fi)
 {
   FILE *fp = fi->ifp;
-  int i, error, UNSUPPORTED;
+  int i, error/*, UNSUPPORTED*/;
   const char *err;
   char *str;
   struct tm time, *ptime;
+  time_t my_epoch;
   Mdc_Main_header7 mh;
   Mdc_Image_subheader7 ish;
   Mdc_Attn_subheader7  ash;
@@ -414,7 +416,7 @@ const char *MdcReadECAT7(FILEINFO *fi)
 
   if (MDC_INFO_DB) return(NULL); /* just needed db info */
 
-  /* check for supported file types */
+  /* check for supported file types *
   switch (mh.file_type) {
     case MDC_ECAT7_FILE_TYPE_IMAGE16 :
     case MDC_ECAT7_FILE_TYPE_VOLUME8 :
@@ -424,7 +426,7 @@ const char *MdcReadECAT7(FILEINFO *fi)
         break;
     default:
         UNSUPPORTED = MDC_YES;
-  }
+  }*/
   /* if (UNSUPPORTED == MDC_YES) return("ECAT7 Unsupported file type"); */
 
   if (mh.num_frames  <= 0 ) mh.num_frames  = 1;
@@ -446,7 +448,7 @@ const char *MdcReadECAT7(FILEINFO *fi)
 
     axial_width = mh.plane_separation * (float)fi->dim[3];
     if ((axial_width - bed_offset) >= 1.0) {
-      MdcPrntWarn("ECAT7 Bed overlaps unsupported"); 
+      MdcPrntWarn("ECAT7 Bed overlaps unsupported");
     }
   }
 
@@ -474,7 +476,7 @@ const char *MdcReadECAT7(FILEINFO *fi)
         fi->pat_slice_orient = MDC_DECUBITUS_LEFT_HEADFIRST_TRANSAXIAL;  break;
     default:
         fi->pat_slice_orient = MDC_SUPINE_HEADFIRST_TRANSAXIAL;
-        MdcPrntWarn("ECAT7 unknown patient orientation"); 
+        MdcPrntWarn("ECAT7 unknown patient orientation");
   }
 
   str = MdcGetStrPatPos(fi->pat_slice_orient);
@@ -496,10 +498,11 @@ const char *MdcReadECAT7(FILEINFO *fi)
   fi->patient_weight = mh.patient_weight;
 
   ptime = &time;
-#ifdef HAVE_LOCALTIME_R
-  localtime_r((time_t *)&(mh.patient_birth_date), ptime);
+  my_epoch = (time_t)mh.patient_birth_date;
+#ifdef LIBMDC_HAVE_LOCALTIME_R
+  localtime_r(&my_epoch, ptime);
 #else
-  ptime = localtime((time_t *)&(mh.patient_birth_date));
+  ptime = localtime(&my_epoch);
 #endif
   if (ptime == NULL) {
     MdcPrntWarn("ECAT7: Couldn't resolve patient birth date");
@@ -507,14 +510,15 @@ const char *MdcReadECAT7(FILEINFO *fi)
   }else{
     sprintf(fi->patient_dob,"%.4d%.2d%.2d",ptime->tm_year + 1900
                                           ,ptime->tm_mon  + 1
-					  ,ptime->tm_mday);
+                                          ,ptime->tm_mday);
   }
 
   ptime = &time;
-#ifdef HAVE_LOCALTIME_R
-  localtime_r((time_t *)&(mh.scan_start_time), ptime);
+#ifdef LIBMDC_HAVE_LOCALTIME_R
+  my_epoch = (time_t)(mh.scan_start_time);
+  localtime_r(&my_epoch, ptime);
 #else
-  ptime = localtime((time_t *)&(mh.scan_start_time));
+  ptime = localtime(&my_epoch);
 #endif
   if (ptime == NULL) {
     MdcPrntWarn("ECAT7: Couldn't resolve scan start time");
@@ -536,18 +540,18 @@ const char *MdcReadECAT7(FILEINFO *fi)
   switch (mh.acquisition_type) {
     case MDC_ECAT7_SCAN_TRANSMISSION:
     case MDC_ECAT7_SCAN_STATIC_EMISSION:
-      fi->acquisition_type = MDC_ACQUISITION_TOMO;    
+      fi->acquisition_type = MDC_ACQUISITION_TOMO;
       break;
     case MDC_ECAT7_SCAN_DYNAMIC_EMISSION:
-      fi->acquisition_type = MDC_ACQUISITION_DYNAMIC; 
+      fi->acquisition_type = MDC_ACQUISITION_DYNAMIC;
       break;
     case MDC_ECAT7_SCAN_GATED_EMISSION:
-      fi->acquisition_type = MDC_ACQUISITION_GSPECT; 
+      fi->acquisition_type = MDC_ACQUISITION_GSPECT;
       break;
     case MDC_ECAT7_SCAN_BLANK:
     case MDC_ECAT7_SCAN_TRANS_RECTILINEAR:
     case MDC_ECAT7_SCAN_EMISSION_RECTILINEAR:
-    default: 
+    default:
       fi->acquisition_type = MDC_ACQUISITION_UNKNOWN;
       break;
   }
@@ -571,7 +575,7 @@ const char *MdcReadECAT7(FILEINFO *fi)
 
   if (!MdcGetStructID(fi,number))
     return("ECAT7 Bad malloc IMG_DATA structs");
- 
+
   /* always malloc dyndata structs */
   if (!MdcGetStructDD(fi,(Uint32)fi->dim[4]*fi->dim[5]*fi->dim[6]))
     return("ECAT7 Couldn't malloc DYNAMIC_DATA structs");
@@ -598,7 +602,7 @@ const char *MdcReadECAT7(FILEINFO *fi)
                                             ,matrix_list[t].endblk
                                             ,matrix_list[t].matstat);
     }
-  } 
+  }
 
   img=0; vol=0;
   for (bed=0; bed<fi->dim[6]; bed++)
@@ -639,7 +643,7 @@ const char *MdcReadECAT7(FILEINFO *fi)
          fi->dim[1] = ish.x_dimension;
          fi->dim[2] = ish.y_dimension;
 
-#if MDC_NUM_PLANES_FIX 
+#if MDC_NUM_PLANES_FIX
          if ((mh.num_planes != ish.z_dimension) && (vol == 0)) {
 
            MdcPrntWarn("ECAT7 Fix wrong num_planes value");
@@ -650,7 +654,7 @@ const char *MdcReadECAT7(FILEINFO *fi)
            for (i=3, number=1; i<=6; i++) number*=fi->dim[i];
            if (!MdcGetStructID(fi,number))
              return("ECAT7 Bad realloc IMG_DATA structs");
- 
+
          }
 #endif
 
@@ -682,10 +686,10 @@ const char *MdcReadECAT7(FILEINFO *fi)
          bytes = fi->dim[1] * fi->dim[2] * fi->dim[3] * MdcType2Bytes(type);
          MdcDebugPrint("volume: %d bytes",bytes);
          bytes = MdcMatrixBlocks(bytes);
- 
+
          MdcDebugPrint("matrix: %d bytes",bytes);
 
-         mbufr = malloc(bytes); 
+         mbufr = malloc(bytes);
          if (mbufr == NULL)
            return("ECAT7 Bad malloc image matrix data buffer");
 
@@ -742,7 +746,7 @@ const char *MdcReadECAT7(FILEINFO *fi)
               return("ECAT7 Bad malloc image buffer");
             }
 
-            memcpy(id->buf, mbufr + (bytes*slice), bytes); 
+            memcpy(id->buf, mbufr + (bytes*slice), bytes);
 
          }
 
@@ -751,7 +755,7 @@ const char *MdcReadECAT7(FILEINFO *fi)
          break;
 
        case MDC_ECAT7_FILE_TYPE_ATTNCORR:
-        
+
          error = mdc_mat_read_attn_subheader7(fp, startblk-1, &ash);
          if (error) return("ECAT7 Bad read attenuation subheader");
 
@@ -793,10 +797,10 @@ const char *MdcReadECAT7(FILEINFO *fi)
          MdcDebugPrint("volume: %d bytes",bytes);
          bytes = MdcMatrixBlocks(bytes);
 
- 
+
          MdcDebugPrint("matrix: %d bytes",bytes);
 
-         mbufr = malloc(bytes); 
+         mbufr = malloc(bytes);
          if (mbufr == NULL)
            return("ECAT7 Bad malloc attenuation matrix data buffer");
 
@@ -882,7 +886,7 @@ const char *MdcReadECAT7(FILEINFO *fi)
               }
             }else{
               /* sinogram mode: fine, just copy */
-              memcpy(id->buf, mbufr + (bytes*slice), bytes); 
+              memcpy(id->buf, mbufr + (bytes*slice), bytes);
             }
 
             group_slice++;
@@ -893,7 +897,7 @@ const char *MdcReadECAT7(FILEINFO *fi)
 
          break;
 
-       default: 
+       default:
 
               return("ECAT7 Unsupported file type");
 
@@ -917,7 +921,7 @@ const char *MdcReadECAT7(FILEINFO *fi)
     case MDC_ECAT7_FILE_TYPE_VOLUME16:
       fi->reconstructed = MDC_YES;
       if (ish.decay_corr_fctr > 1.0) fi->decay_corrected = MDC_YES;
-      break; 
+      break;
     default:
       fi->reconstructed = MDC_NO;
   }
@@ -925,7 +929,7 @@ const char *MdcReadECAT7(FILEINFO *fi)
   MdcCloseFile(fi->ifp);
 
   if (fi->truncated) return("ECAT7 Truncated image file");
- 
+
   return(NULL);
 
 }
@@ -951,12 +955,12 @@ int MdcConvertToTPCEcat7image(FILEINFO* fi,
 #if MDC_TPC_SITE
     case MDC_SAGITTAL:
       /* short int <- Int16 */
-      h->x_dimension = fi->dim[3];      
+      h->x_dimension = fi->dim[3];
       h->y_dimension = fi->dim[2];
       h->z_dimension = fi->dim[1];
       /* float <- ??? */
-      h->x_offset = 0;                  
-      h->y_offset = 0;    
+      h->x_offset = 0;
+      h->y_offset = 0;
       h->z_offset = 0;
       h->x_pixel_size = fi->pixdim[3]/10;
       h->y_pixel_size = fi->pixdim[2]/10;
@@ -1058,12 +1062,16 @@ int MdcConvertToTPCEcat7image(FILEINFO* fi,
   h->decay_corr_fctr = 0.0f;
   /* int <- ??? */
   h->processing_code = 0;
-  if (fi->gdata) {
+  if (fi->gatednr > 0 && fi->gdata != NULL) {
     /* int <- float (ms) */
-    h->gate_duration = fi->gdata->image_duration;
+    h->gate_duration = fi->gdata[0].image_duration;
     /* int <- float (ms) */
-    h->r_wave_offset = fi->gdata->window_low;
-    h->num_accepted_beats = fi->gdata->cycles_acquired;
+    h->r_wave_offset = fi->gdata[0].window_low;
+    h->num_accepted_beats = fi->gdata[0].cycles_acquired;
+  }else{
+    h->gate_duration = 0;
+    h->r_wave_offset = 0;
+    h->num_accepted_beats = 0;
   }
   /* float <- ??? */
   h->filter_cutoff_frequency = 0.0f;
@@ -1077,7 +1085,8 @@ int MdcConvertToTPCEcat7image(FILEINFO* fi,
   h->filter_scatter_fraction = 0.0f;
   /* float <- ??? */
   h->filter_scatter_slope = 0.0f;
-/* char annotation[40]; */
+  /* char annotation[40]; */
+  for(i = 0; i < 40; i++) h->annotation[i] = '\0';
   /* float <- ??? */
   h->mt_1_1 = 0.0f;
   /* float <- ??? */
@@ -1095,7 +1104,7 @@ int MdcConvertToTPCEcat7image(FILEINFO* fi,
   /* float <- ??? */
   h->mt_3_2 = 0.0f;
   /* float <- ??? */
-  h->mt_2_3 = 0.0f;
+  h->mt_3_3 = 0.0f;
   /* float <- ??? */
   h->rfilter_cutoff = 0.0f;
   /* float <- ??? */
@@ -1139,7 +1148,7 @@ int MdcConvertToTPCEcat7image(FILEINFO* fi,
  * @param mh pointer to MDC mainheader
  * @param h pointer to TPC mainheader
  */
-int MdcConvertToTPCEcat7(FILEINFO* fi, 
+int MdcConvertToTPCEcat7(FILEINFO* fi,
                          Mdc_Main_header* mh, ECAT7_mainheader* h)
 {
   struct tm timeinfo;
@@ -1313,7 +1322,7 @@ const char *MdcWriteECAT7(FILEINFO *fi)
   float* TPC_frame = 0;
   float* TPC_frame_start = 0;
   int frame_size = 0;
-  int plane_dir = 0;
+/*  int plane_dir = 0;*/
   Uint32 uwidth, uheight;
   IMG_DATA *id;
   Mdc_Main_header mh;
@@ -1380,13 +1389,13 @@ const char *MdcWriteECAT7(FILEINFO *fi)
     return("ECAT7 Failed to allocate frame buffer");
   }
 
-  if ( ! ( fi->pat_slice_orient == MDC_TRANSAXIAL || 
+  if ( ! ( fi->pat_slice_orient == MDC_TRANSAXIAL ||
            fi->pat_slice_orient == MDC_CORONAL    ||
            fi->pat_slice_orient == MDC_SAGITTAL   )) {
     MdcPrntWarn("ECAT7 Couldn't resolve slice orientation, using transaxial\n");
   }
 
-  /* head feet direction L\P,L\FP,P\F,L\F,P\FR,R\F */
+  /* head feet direction L\P,L\FP,P\F,L\F,P\FR,R\F
   plane_dir = MDC_HEADFIRST;
   if      (strcmp(fi->pat_orient,"L\\P")  == 0) plane_dir = MDC_FEETFIRST;
   else if (strcmp(fi->pat_orient,"R\\P")  == 0) plane_dir = MDC_FEETFIRST;
@@ -1397,7 +1406,7 @@ const char *MdcWriteECAT7(FILEINFO *fi)
   else if (strcmp(fi->pat_orient,"R\\F")  == 0) plane_dir = MDC_HEADFIRST;
   else {
     MdcPrntWarn("ECAT7 Unrecognized patient orientation: %s\n",fi->pat_orient);
-  }
+  }*/
 
   for (bed=0; bed <= mh.num_bed_pos; bed++)
   for (gate=1; gate <= mh.num_gates; gate++)
@@ -1459,8 +1468,8 @@ const char *MdcWriteECAT7(FILEINFO *fi)
        for (column=0; column < uwidth; column++)
        for (row=0; row < uheight*bytes; row+=bytes) {
           flt32 = *((float*)&maxbuf[column*uheight*bytes+row]);
-          *(TPC_frame + ((plane)*uheight*uwidth 
-                      + column*uheight 
+          *(TPC_frame + ((plane)*uheight*uwidth
+                      + column*uheight
                       + (row/bytes))) = flt32;
        }
 #else
