@@ -16,11 +16,11 @@
  *                MdcWriteINW()         - Write INW file                   *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-inw.c,v 1.41 2011/12/27 00:46:06 enlf Exp $
+/*
  */
 
 /*
-   Copyright (C) 1997-2012 by Erik Nolf
+   Copyright (C) 1997-2026 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -43,13 +43,13 @@
 #include "m-depend.h"
 
 #include <stdio.h>
-#ifdef HAVE_STDLIB_H
+#ifdef LIBMDC_HAVE_STDLIB_H
 #include <stdlib.h>
 #endif
-#ifdef HAVE_STRING_H
+#ifdef LIBMDC_HAVE_STRING_H
 #include <string.h>
 #endif
-#ifdef HAVE_STRINGS_H
+#ifdef LIBMDC_HAVE_STRINGS_H
 #ifndef _WIN32
 #include <strings.h>
 #endif
@@ -67,7 +67,7 @@ int MdcCheckINW(FILEINFO *fi)
 
   MDC_FILE_ENDIAN = MDC_LITTLE_ENDIAN;    /* always */
 
-  if (fread((char *)&hs,1,MDC_INW_HEAD_START_SIZE,fi->ifp) 
+  if (fread((char *)&hs,1,MDC_INW_HEAD_START_SIZE,fi->ifp)
     != MDC_INW_HEAD_START_SIZE) return(MDC_BAD_READ);
 
   MdcSWAP(hs.mark);
@@ -85,7 +85,7 @@ char *MdcReadINW(FILEINFO *fi)
   MDC_INW_HEAD_GEN   hg;
   MDC_INW_HEAD_SPEC  *hsp;
   IMG_DATA   *id;
-  Uint32 i, bytes, number; 
+  Uint32 i, bytes, number;
   char *err=NULL;
 
   if (MDC_PROGRESS) MdcProgress(MDC_PROGRESS_BEGIN,0.,"Reading INW:");
@@ -99,7 +99,7 @@ char *MdcReadINW(FILEINFO *fi)
   memset(&hs,0,MDC_INW_HEAD_START_SIZE);
   memset(&hg,0,MDC_INW_HEAD_GEN_SIZE);
 
-  if (fread((char *)&hs,1,MDC_INW_HEAD_START_SIZE,fp) 
+  if (fread((char *)&hs,1,MDC_INW_HEAD_START_SIZE,fp)
     != MDC_INW_HEAD_START_SIZE) return("INW  Bad read HeadStart struct");
 
   /* put some defaults we use */
@@ -137,7 +137,7 @@ char *MdcReadINW(FILEINFO *fi)
     MdcPrntScrn("\n");
 
     MdcPrntScrn("\nHEAD GEN   (%d bytes)\n",MDC_INW_HEAD_GEN_SIZE);
-    MdcPrintLine('-',MDC_HALF_LENGTH); 
+    MdcPrintLine('-',MDC_HALF_LENGTH);
     MdcPrntScrn("number planes : %hd\n",hg.no);
     MdcPrntScrn("number columns: %hd\n",hg.sizeX);
     MdcPrntScrn("number rows   : %hd\n",hg.sizeY);
@@ -154,7 +154,7 @@ char *MdcReadINW(FILEINFO *fi)
     switch (hg.scanner) {
       case  EcatII: MdcPrntScrn("(EcatII)");        break;
       case  EcatIV: MdcPrntScrn("(EcatIV)");        break;
-      default     : MdcPrntScrn("(Unknown)"); 
+      default     : MdcPrntScrn("(Unknown)");
     }
     MdcPrntScrn("\n");
     MdcPrntScrn("recon type    : %c ",hg.reconstruction);
@@ -179,7 +179,7 @@ char *MdcReadINW(FILEINFO *fi)
     return("INW  Unsupported pixel type");
 
   if (hs.version != (Int16)(MDC_INW_VERS_HIGH*256 + MDC_INW_VERS_LOW))
-    return("INW  Unsupported version"); 
+    return("INW  Unsupported version");
 
   /* fill in the FILEINFO struct */
   number = hg.no;
@@ -191,9 +191,7 @@ char *MdcReadINW(FILEINFO *fi)
      case 1: fi->type = BIT8_U; break;
      case 2: fi->type = BIT16_S; break; /* only this is supported */
      case 4: fi->type = BIT32_S; break;
-#ifdef HAVE_8BYTE_INT
      case 8: fi->type = BIT64_S; break;
-#endif
   }
   fi->dim[0] = 3;
   fi->dim[1] = hg.sizeX;
@@ -209,20 +207,20 @@ char *MdcReadINW(FILEINFO *fi)
                            ,"Filtered Backprojection");
                         break;
     case reconMaxLikFV: strcpy(fi->recon_method
-                           ,"Maximum likelihood F. Vermeulen"); 
+                           ,"Maximum likelihood F. Vermeulen");
                         break;
     case reconMaxLik  : strcpy(fi->recon_method
-                           ,"Maximum likelihood T. De Backer"); 
+                           ,"Maximum likelihood T. De Backer");
                         break;
     case reconMaxPos  : strcpy(fi->recon_method
-                           ,"Maximum a Posteriori"); 
+                           ,"Maximum a Posteriori");
                         break;
   }
 
 
   /* now we read the spec/image headers */
 
-  if ((hsp = (MDC_INW_HEAD_SPEC *)malloc(MDC_INW_HEAD_SPEC_SIZE*number)) 
+  if ((hsp = (MDC_INW_HEAD_SPEC *)malloc(MDC_INW_HEAD_SPEC_SIZE*number))
            == NULL)
     return("INW  Bad malloc HeadSpec structs");
 
@@ -262,7 +260,7 @@ char *MdcReadINW(FILEINFO *fi)
 
      if (hsp[i].trans < 0.0 ) hsp[i].trans = - hsp[i].trans; /* positive */
 
-     /* fill in the IMG_DATA struct */ 
+     /* fill in the IMG_DATA struct */
      id->width = fi->mwidth;
      id->height = fi->mheight;
      id->bits  = fi->bits;
@@ -290,7 +288,7 @@ char *MdcReadINW(FILEINFO *fi)
     /* unknown slice_width */
   }else{
     /* slice_width = relative translation from next slice */
-    fi->pixdim[3] = 0.0; 
+    fi->pixdim[3] = 0.0;
     for (i=0; i<fi->number-1; i++) {
        if (hsp[i].trans > hsp[i+1].trans) {
          fi->image[i].slice_width = hsp[i].trans - hsp[i+1].trans;
@@ -316,7 +314,7 @@ char *MdcReadINW(FILEINFO *fi)
      id->slice_spacing = id->slice_width;
      MdcFillImgPos(fi,i,i,0.0);
      MdcFillImgOrient(fi,i);
-  } 
+  }
 
   MdcFree(hsp);
 
@@ -326,7 +324,7 @@ char *MdcReadINW(FILEINFO *fi)
 
   return NULL;
 
-}   
+}
 
 
 int MdcWriteHeadStart(FILEINFO *fi)
@@ -338,7 +336,7 @@ int MdcWriteHeadStart(FILEINFO *fi)
   hs.mark = MDC_INW_SIG;
   hs.version = MDC_INW_VERS_HIGH*256 + MDC_INW_VERS_LOW;
   hs.size_header = (Int16)( (MDC_INW_HEAD_SPEC_SIZE * fi->number)
-                           + MDC_INW_HEAD_START_SIZE + MDC_INW_HEAD_GEN_SIZE); 
+                           + MDC_INW_HEAD_START_SIZE + MDC_INW_HEAD_GEN_SIZE);
   hs.size_start = MDC_INW_HEAD_START_SIZE;
   hs.size_gen   = MDC_INW_HEAD_GEN_SIZE;
   hs.size_spec  = MDC_INW_HEAD_SPEC_SIZE;
@@ -382,9 +380,9 @@ int MdcWriteHeadGen(FILEINFO *fi)
 
   MdcSWAP(hg.no);         MdcSWAP(hg.sizeX);        MdcSWAP(hg.sizeY);
   MdcSWAP(hg.pixel_type); MdcSWAP(hg.init_trans);   MdcSWAP(hg.dummy1);
-  MdcSWAP(hg.time);       MdcSWAP(hg.scanner);      
+  MdcSWAP(hg.time);       MdcSWAP(hg.scanner);
 
-  if (fwrite((char *)&hg,1,MDC_INW_HEAD_GEN_SIZE,fi->ofp) 
+  if (fwrite((char *)&hg,1,MDC_INW_HEAD_GEN_SIZE,fi->ofp)
     != MDC_INW_HEAD_GEN_SIZE) return(MDC_NO);
 
   return(MDC_YES);
@@ -392,14 +390,14 @@ int MdcWriteHeadGen(FILEINFO *fi)
 }
 
 int MdcSkipHeadSpecs(FILEINFO *fi)
-{ 
+{
   Uint32 i;
   MDC_INW_HEAD_SPEC hsp;
 
   memset(&hsp,0,MDC_INW_HEAD_SPEC_SIZE);
 
   for (i=0; i < fi->number; i++)
-     if (fwrite((char *)&hsp,1,MDC_INW_HEAD_SPEC_SIZE,fi->ofp) 
+     if (fwrite((char *)&hsp,1,MDC_INW_HEAD_SPEC_SIZE,fi->ofp)
        != MDC_INW_HEAD_SPEC_SIZE) return MDC_NO;
 
   return MDC_YES;
@@ -407,12 +405,12 @@ int MdcSkipHeadSpecs(FILEINFO *fi)
 
 int MdcWriteHeadSpecs(FILEINFO *fi)
 {
-  IMG_DATA *id; 
+  IMG_DATA *id;
   MDC_INW_HEAD_SPEC hsp;
 
   Uint32 img;
 
-  fseek(fi->ofp,MDC_INW_HEAD_START_SIZE + MDC_INW_HEAD_GEN_SIZE,SEEK_SET);
+  fseeko(fi->ofp,MDC_INW_HEAD_START_SIZE + MDC_INW_HEAD_GEN_SIZE,SEEK_SET);
 
   for (img=0; img < fi->number; img++) {
 
@@ -420,7 +418,7 @@ int MdcWriteHeadSpecs(FILEINFO *fi)
 
      id = &fi->image[img];
 
-     hsp.time = 0;   
+     hsp.time = 0;
      if (id->rescaled) {
        hsp.max     = (Int16)id->rescaled_max;
        hsp.min     = (Int16)id->rescaled_min;
@@ -443,7 +441,7 @@ int MdcWriteHeadSpecs(FILEINFO *fi)
      MdcSWAP(hsp.time);          MdcSWAP(hsp.trans);
      MdcSWAP(hsp.max);           MdcSWAP(hsp.min);
 
-     if (fwrite((char *)&hsp,1,MDC_INW_HEAD_SPEC_SIZE,fi->ofp) 
+     if (fwrite((char *)&hsp,1,MDC_INW_HEAD_SPEC_SIZE,fi->ofp)
        != MDC_INW_HEAD_SPEC_SIZE) return(MDC_NO);
 
   }
@@ -460,14 +458,14 @@ char *MdcWriteINW(FILEINFO *fi)
   Uint32 i, p, size;
   Uint8 *buf, *maxbuf;
   int FREE=MDC_NO, type = BIT16_S; /* only supported type in version 1.0 */
- 
+
   MDC_FILE_ENDIAN = MDC_LITTLE_ENDIAN; /* always */
 
   if (MDC_FORCE_INT != MDC_NO) {
     if (MDC_FORCE_INT != BIT16_S) {
       MdcPrntWarn("INW  Only Int16 pixels supported");
     }
-  } 
+  }
 
   if (XMDC_GUI == MDC_NO) {
     MdcDefaultName(fi,MDC_FRMT_INW,fi->ofname,fi->ifname);
@@ -491,7 +489,7 @@ char *MdcWriteINW(FILEINFO *fi)
   }
 
   if ( !MdcWriteHeadStart(fi) )return("INW  Bad write HeadStart struct");
- 
+
   if ( !MdcWriteHeadGen(fi) )  return("INW  Bad write HeadGen struct");
 
   if ( !MdcSkipHeadSpecs(fi) ) return("INW  Bad skipping HeadSpecs structs");
@@ -507,10 +505,10 @@ char *MdcWriteINW(FILEINFO *fi)
        buf = MdcGetImgBIT16_S(fi, i);
        FREE=MDC_YES; type=BIT16_S;
      }else{
-       buf = id->buf; 
+       buf = id->buf;
        FREE=MDC_NO; type=id->type;
      }
- 
+
      if (buf == NULL) return("INW  Bad malloc image buffer");
 
      /* write images with uniform sizes */
@@ -531,8 +529,8 @@ char *MdcWriteINW(FILEINFO *fi)
      }
 
      for (p=0; p < size; p += MdcType2Bytes(type)) {
-        value=MdcGetDoublePixel((Uint8 *)&maxbuf[p],type); 
-	MdcWriteDoublePixel(value,type,fi->ofp);
+        value=MdcGetDoublePixel((Uint8 *)&maxbuf[p],type);
+        MdcWriteDoublePixel(value,type,fi->ofp);
      }
 
      if (FREE) MdcFree(maxbuf);
@@ -547,5 +545,5 @@ char *MdcWriteINW(FILEINFO *fi)
 
   MdcCloseFile(fi->ofp);
 
-  return NULL; 
+  return NULL;
 }
