@@ -8,8 +8,11 @@
  * project      : (X)MedCon by Erik Nolf                                   *
  *                                                                         *
  * Functions    : MdcReadRAW()          - Read raw images interactive      *
- *                MdcWriteRAW()         - Write raw images to file         * 
+ *                MdcWriteRAW()         - Write raw images to file         *
  *                MdcInitRawPrevInput() - Initialize previous inputs       *
+ *                MdcGetRawInput()      - Get raw image layout from user   *
+ *                MdcUsePrevRawInput()  - Use previus raw layout settings  *
+ *                MdcAskRawInput()      - Ask raw layout from user         *
  *                MdcReadPredef()       - Read  predefined RAW settings    *
  *                MdcWritePredef()      - Write predefined RAW settings    *
  *                                                                         *
@@ -17,11 +20,11 @@
  *                the headersize to skip and the pixel data type           *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-raw.c,v 1.44 2011/12/27 00:46:06 enlf Exp $
+/*
  */
 
 /*
-   Copyright (C) 1997-2012 by Erik Nolf
+   Copyright (C) 1997-2026 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -44,13 +47,13 @@
 #include "m-depend.h"
 
 #include <stdio.h>
-#ifdef HAVE_STDLIB_H
+#ifdef LIBMDC_HAVE_STDLIB_H
 #include <stdlib.h>
 #endif
-#ifdef HAVE_STRING_H
+#ifdef LIBMDC_HAVE_STRING_H
 #include <string.h>
 #endif
-#ifdef HAVE_STRINGS_H
+#ifdef LIBMDC_HAVE_STRINGS_H
 #ifndef _WIN32
 #include <strings.h>
 #endif
@@ -59,7 +62,7 @@
 #include "medcon.h"
 
 /****************************************************************************
-                              D E F I N E S 
+                              D E F I N E S
 ****************************************************************************/
 
 #define MDC_PREDEFSIG "# RPI v0.1"     /* predef signature    */
@@ -77,20 +80,259 @@ void MdcInitRawPrevInput(void)
    prev->XDIM=0; prev->YDIM=0; prev->NRIMGS=1;
    prev->GENHDR=0; prev->IMGHDR=0; prev->ABSHDR=0;
    prev->PTYPE = BIT16_S;
-   prev->DIFF  = MDC_NO; prev->HDRREP=MDC_NO; prev->PSWAP=MDC_NO;
+   prev->DIFF  = MDC_NO; prev->HDRREP = MDC_NO; prev->PSWAP = MDC_NO;
+   prev->REDO  = MDC_YES; /* required for first time to ask parameters */
 }
 
+char *MdcGetRawInput(FILEINFO *fi)
+{
+  MdcRawPrevInputStruct *prev = &mdcrawprevinput;
+  char *msg;
+
+  if (XMDC_GUI == MDC_YES) return(NULL); /* procedure not used in GUI */
+
+  if (prev->REDO == MDC_NO) {
+    msg = MdcUsePrevRawInput(fi);
+  }else{
+    msg = MdcAskRawInput(fi);
+  }
+
+  return(msg);
+}
+
+char *MdcUsePrevRawInput(FILEINFO *fi)
+{
+  MdcRawPrevInputStruct *prev = &mdcrawprevinput;
+  IMG_DATA *id=NULL;
+  Uint32 i;
+
+  /* use previous settings */
+  if (!MdcGetStructID(fi,prev->NRIMGS))
+    return("RAW  Bad malloc IMG_DATA structs from previous settings.");
+
+  /* prepare FILEINFO structure */
+  for (i=0; i<fi->number; i++) {
+
+     id = &fi->image[i];
+
+     id->width  = prev->XDIM;
+     id->height = prev->YDIM;
+     id->type   = prev->PTYPE;
+     id->bits   = MdcType2Bits(id->type);
+  }
+
+  if (prev->PSWAP == MDC_YES) {
+    MDC_FILE_ENDIAN = !MDC_HOST_ENDIAN;
+  }else{
+    MDC_FILE_ENDIAN = MDC_HOST_ENDIAN;
+  }
+
+  fi->endian = MDC_FILE_ENDIAN;
+  fi->dim[0] = 3;
+  fi->dim[3] = fi->number;
+
+  return(NULL);
+}
+
+char *MdcAskRawInput(FILEINFO *fi)
+{
+  MdcRawInputStruct *input = &mdcrawinput;
+  MdcRawPrevInputStruct *prev = &mdcrawprevinput;
+  IMG_DATA *id=NULL;
+  Uint32 i, number;
+
+  /* init input entries */
+  input->gen_offset=0;
+  input->img_offset=0;
+  input->REPEAT=MDC_NO;
+  input->DIFF=MDC_NO;
+  input->REDO=MDC_NO;
+
+  MDC_FILE_ENDIAN = MDC_HOST_ENDIAN;
+
+  MdcPrintLine('-',MDC_FULL_LENGTH);
+  MdcPrntScrn("\tINTERACTIVE  PROCEDURE\n");
+  MdcPrintLine('-',MDC_FULL_LENGTH);
+
+  number = prev->NRIMGS;
+
+  MdcPrntScrn("\n\tFilename: %s\n\n",fi->ifname);
+  MdcPrntScrn("\tNumber of images [%u]? ",number);
+  if (!MdcPutDefault(mdcbufr)) {
+    number = (Uint32)atol(mdcbufr); prev->NRIMGS=number;
+  }
+  if (number == 0) return("RAW  No images specified");
+
+  if (!MdcGetStructID(fi,number))
+    return("RAW  Bad malloc IMG_DATA structs");
+
+  MdcPrntScrn("\tGeneral header offset to binary data [%jd bytes]? "
+                ,(intmax_t)prev->GENHDR);
+  if (MdcPutDefault(mdcbufr)) input->gen_offset = prev->GENHDR;
+  else{
+      input->gen_offset = (off_t)atoll(mdcbufr);
+      prev->GENHDR = input->gen_offset;
+  }
+  MdcPrntScrn("\tImage   header offset to binary data [%jd bytes]? "
+                ,(intmax_t)prev->IMGHDR);
+  if (MdcPutDefault(mdcbufr)) input->img_offset = prev->IMGHDR;
+  else{
+      input->img_offset = (off_t)atoll(mdcbufr);
+      prev->IMGHDR = input->img_offset;
+  }
+  MdcPrntScrn("\tImage   header repeated before each image ");
+  sprintf(mdcbufr,"%s",MdcGetStrYesNo(prev->HDRREP));
+  MdcPrntScrn("[%s]? ",mdcbufr);
+  if (!MdcPutDefault(mdcbufr)) {
+    if (mdcbufr[0]=='y' || mdcbufr[0]=='Y') {
+      input->REPEAT = MDC_YES; prev->HDRREP = MDC_YES;
+    }else{
+      input->REPEAT = MDC_NO;  prev->HDRREP = MDC_NO;
+    }
+  }else{
+    input->REPEAT = prev->HDRREP;
+  }
+
+  MdcPrntScrn("\tSwap the pixel bytes ");
+  sprintf(mdcbufr,"%s",MdcGetStrYesNo(prev->PSWAP));
+  MdcPrntScrn("[%s]? ",mdcbufr);
+  if (!MdcPutDefault(mdcbufr)) {
+    if (mdcbufr[0]=='y' || mdcbufr[0]=='Y') {
+      MDC_FILE_ENDIAN = !MDC_HOST_ENDIAN; prev->PSWAP = MDC_YES;
+    }else{
+      MDC_FILE_ENDIAN = MDC_HOST_ENDIAN;  prev->PSWAP = MDC_NO;
+    }
+  }else{
+    if (prev->PSWAP == MDC_YES) {
+      MDC_FILE_ENDIAN = !MDC_HOST_ENDIAN;
+    }else{
+      MDC_FILE_ENDIAN = MDC_HOST_ENDIAN;
+    }
+  }
+
+  MdcPrntScrn("\tSame characteristics for all images ");
+  sprintf(mdcbufr,"%s",MdcGetStrYesNo(!prev->DIFF));
+  MdcPrntScrn("[%s]? ",mdcbufr);
+  if (!MdcPutDefault(mdcbufr)) {
+    if (mdcbufr[0]=='n' || mdcbufr[0]=='N') {
+      input->DIFF=MDC_YES; prev->DIFF = MDC_YES;
+    }else{
+      input->DIFF=MDC_NO;  prev->DIFF = MDC_NO;
+    }
+  }else{
+    input->DIFF = prev->DIFF;
+  }
+
+  for (i=0; i<fi->number; i++) {
+
+     id = &fi->image[i];
+
+     if (input->DIFF) {
+       MdcPrntScrn("\n\tIMAGE #%03u\n",i+1);
+       MdcPrntScrn("\t----------\n");
+     }else if (i==0) {
+       MdcPrntScrn("\n\tALL IMAGES\n");
+       MdcPrntScrn("\t----------\n");
+     }
+
+     /* put default */
+     if (i==0) id->type = prev->PTYPE;
+
+     if (input->DIFF || (!input->DIFF && i==0)) {
+
+       MdcPrntScrn("\tAbsolute offset in bytes [%jd]? ",(intmax_t)prev->ABSHDR);
+       if (MdcPutDefault(mdcbufr)) id->load_location = prev->ABSHDR;
+       else{
+         id->load_location = (off_t)atoll(mdcbufr);
+         prev->ABSHDR = id->load_location;
+       }
+
+       MdcPrntScrn("\tImage columns [%u]? ",prev->XDIM);
+       if (MdcPutDefault(mdcbufr)) id->width = prev->XDIM;
+       else{ id->width = (Uint32)atol(mdcbufr); prev->XDIM = id->width; }
+       if (id->width == 0) return("RAW  No width specified");
+
+       MdcPrntScrn("\tImage rows    [%u]? ",prev->YDIM);
+       if (MdcPutDefault(mdcbufr)) id->height = prev->YDIM;
+       else{ id->height = (Uint32)atol(mdcbufr); prev->YDIM = id->height; }
+       if (id->height == 0) return("RAW  No height specified");
+
+       MdcPrntScrn("\tPixel data type:\n\n");
+       MdcPrntScrn("\t\t %2d  ->  bit\n",BIT1);
+       MdcPrntScrn("\t\t %2d  ->  Int8 \t\t %2d -> Uint8\n",BIT8_S,BIT8_U);
+       MdcPrntScrn("\t\t %2d  ->  Int16\t\t %2d -> Uint16\n",BIT16_S,BIT16_U);
+       MdcPrntScrn("\t\t %2d  ->  Int32\t\t %2d -> Uint32\n",BIT32_S,BIT32_U);
+       MdcPrntScrn("\t\t %2d  ->  Int64\t\t %2d -> Uint64\n",BIT64_S,BIT64_U);
+       MdcPrntScrn("\t\t %2d  ->  float\t\t %2d -> double\n",FLT32,FLT64);
+       MdcPrntScrn("\t\t %2d  ->  ascii\n",ASCII);
+       MdcPrntScrn("\t\t %2d  ->  RGB\n\n",COLRGB);
+       MdcPrntScrn("\tYour choice [%hu]? ", prev->PTYPE);
+
+       if (MdcPutDefault(mdcbufr)) id->type = prev->PTYPE;
+       else{ id->type = (Int16)atoi(mdcbufr); prev->PTYPE = id->type; }
+       MdcPrntScrn("\n");
+
+     }else{
+
+       id->width = prev->XDIM;
+       id->height = prev->YDIM;
+       id->type  = prev->PTYPE;
+       id->load_location = prev->ABSHDR;
+     }
+
+     switch (id->type) {
+         case  BIT1   :
+         case  BIT8_S :
+         case  BIT8_U :
+         case  BIT16_S:
+         case  BIT16_U:
+         case  BIT32_S:
+         case  BIT32_U:
+         case  BIT64_S:
+         case  BIT64_U:
+         case  FLT32  :
+         case  FLT64  :
+         case  ASCII  :
+         case  COLRGB : id->bits = MdcType2Bits(id->type); break;
+         default      : return("RAW  Unsupported data type");
+     }
+  }
+
+  fi->endian = MDC_FILE_ENDIAN;
+  fi->dim[0] = 3;
+  fi->dim[3] = fi->number;
+
+  MdcPrintImageLayout(fi,input->gen_offset,input->img_offset,input->REPEAT);
+
+  MdcPrntScrn("\n\tRedo input for next file ");
+  sprintf(mdcbufr,"%s",MdcGetStrYesNo(prev->REDO));
+  MdcPrntScrn("[%s]? ",mdcbufr);
+  if (!MdcPutDefault(mdcbufr)) {
+    if (mdcbufr[0]=='y' || mdcbufr[0]=='Y') {
+      input->REDO=MDC_YES; prev->REDO=MDC_YES;
+    }else{
+      input->REDO=MDC_NO; prev->REDO=MDC_NO;
+    }
+  }else{
+    if (prev->REDO == MDC_YES) {
+      input->REDO=MDC_YES; prev->REDO=MDC_YES;
+    }else{
+      input->REDO=MDC_NO; prev->REDO=MDC_NO;
+    }
+  }
+
+  return(NULL);
+}
 
 /* read raw images */
 char *MdcReadRAW(FILEINFO *fi)
 {
   MdcRawInputStruct *input = &mdcrawinput;
-  MdcRawPrevInputStruct *prev = &mdcrawprevinput;
   IMG_DATA *id=NULL;
-  Uint32 i, p, bytes, number;
-  int AGAIN;
+  Uint32 i, p, bytes;
   double *pix=NULL;
   char *err=NULL;
+  int r;
 
 
   if (MDC_FILE_STDIN == MDC_YES)
@@ -101,221 +343,39 @@ char *MdcReadRAW(FILEINFO *fi)
   /* put some defaults we use */
   fi->map = MDC_MAP_GRAY;
 
-  if (XMDC_GUI == MDC_NO) 
-  do { /* ask command-line info */
-    input->gen_offset=0;
-    input->img_offset=0;
-    input->REPEAT=MDC_NO;
-    input->DIFF=MDC_NO;
-    input->abs_offset=NULL;
-    AGAIN=MDC_NO;
-
-    MDC_FILE_ENDIAN = MDC_HOST_ENDIAN;
- 
-    MdcPrintLine('-',MDC_FULL_LENGTH);
-    MdcPrntScrn("\tINTERACTIVE  PROCEDURE\n");
-    MdcPrintLine('-',MDC_FULL_LENGTH);
-
-    number = prev->NRIMGS;
-
-    MdcPrntScrn("\n\tFilename: %s\n\n",fi->ifname);
-    MdcPrntScrn("\tNumber of images [%u]? ",number);
-    if (!MdcPutDefault(mdcbufr)) 
-      number = (Uint32)atol(mdcbufr); prev->NRIMGS=number;
-    if (number == 0) return("RAW  No images specified");
-
-    if (!MdcGetStructID(fi,number))
-      return("RAW  Bad malloc IMG_DATA structs");
-
-    MdcPrntScrn("\tGeneral header offset to binary data [%u bytes]? "
-                  ,prev->GENHDR);
-      if (MdcPutDefault(mdcbufr)) input->gen_offset = prev->GENHDR; 
-      else{
-        input->gen_offset = (Uint32)atol(mdcbufr);
-        prev->GENHDR = input->gen_offset;
-      }
-    MdcPrntScrn("\tImage   header offset to binary data [%u bytes]? "
-                  ,prev->IMGHDR);
-      if (MdcPutDefault(mdcbufr)) input->img_offset = prev->IMGHDR;
-      else{
-        input->img_offset = (Uint32)atol(mdcbufr);
-        prev->IMGHDR = input->img_offset;
-      }
-    MdcPrntScrn("\tImage   header repeated before each image ");
-    sprintf(mdcbufr,"%s",MdcGetStrYesNo(prev->HDRREP));
-    MdcPrntScrn("[%s]? ",mdcbufr); 
-      if (!MdcPutDefault(mdcbufr)) { 
-        if (mdcbufr[0]=='y' || mdcbufr[0]=='Y') {
-          input->REPEAT = MDC_YES; prev->HDRREP = MDC_YES;
-        }else{
-          input->REPEAT = MDC_NO;  prev->HDRREP = MDC_NO;
-        }
-      }else{
-         input->REPEAT = prev->HDRREP;
-      }
-      
-    MdcPrntScrn("\tSwap the pixel bytes ");
-    sprintf(mdcbufr,"%s",MdcGetStrYesNo(prev->PSWAP));
-    MdcPrntScrn("[%s]? ",mdcbufr);
-      if (!MdcPutDefault(mdcbufr)) {
-        if (mdcbufr[0]=='y' || mdcbufr[0]=='Y') {
-          MDC_FILE_ENDIAN = !MDC_HOST_ENDIAN; prev->PSWAP = MDC_YES;
-         }else{
-          MDC_FILE_ENDIAN = MDC_HOST_ENDIAN;  prev->PSWAP = MDC_NO; 
-         }
-      }else{
-        if (prev->PSWAP == MDC_YES) {
-          MDC_FILE_ENDIAN = !MDC_HOST_ENDIAN;
-        }else{
-          MDC_FILE_ENDIAN = MDC_HOST_ENDIAN;
-        }
-      }
-          
-    MdcPrntScrn("\tSame characteristics for all images ");
-    sprintf(mdcbufr,"%s",MdcGetStrYesNo(!prev->DIFF));
-    MdcPrntScrn("[%s]? ",mdcbufr);
-      if (!MdcPutDefault(mdcbufr)) {
-        if (mdcbufr[0]=='n' || mdcbufr[0]=='N') {
-          input->DIFF=MDC_YES; prev->DIFF = MDC_YES;
-        }else{
-          input->DIFF=MDC_NO;  prev->DIFF = MDC_NO;
-        }
-      }else{
-        input->DIFF = prev->DIFF;
-      }
-
-    /* malloc abs_offset[] */
-    input->abs_offset=(Uint32 *)malloc(fi->number*sizeof(Uint32));
-    if ( input->abs_offset == NULL ) {
-      return("Couldn't malloc abs_offset[]");
-    }else{
-      memset(input->abs_offset,0,fi->number*sizeof(Uint32));
-    } 
-   
- 
-    for (i=0; i<fi->number; i++) {
-
-       if (MDC_PROGRESS)
-         MdcProgress(MDC_PROGRESS_INCR,1./(float)fi->number,NULL);
- 
-       id = &fi->image[i];
-
-       if (input->DIFF) {
-         MdcPrntScrn("\n\tIMAGE #%03u\n",i+1);
-         MdcPrntScrn("\t----------\n");
-       }else if (i==0) {
-         MdcPrntScrn("\n\tALL IMAGES\n"); 
-         MdcPrntScrn("\t----------\n");
-       }
-
-       /* put default */
-       if (i==0) id->type = prev->PTYPE;
-
-       if (input->DIFF || (!input->DIFF && i==0)) {
-
-         MdcPrntScrn("\tAbsolute offset in bytes [%u]? ",prev->ABSHDR);
-           if (MdcPutDefault(mdcbufr)) input->abs_offset[i] = prev->ABSHDR;
-           else{ 
-             input->abs_offset[i] = (Uint32)atol(mdcbufr);
-             prev->ABSHDR = input->abs_offset[i];
-           }
-         MdcPrntScrn("\tImage columns [%u]? ",prev->XDIM); 
-           if (MdcPutDefault(mdcbufr)) id->width = prev->XDIM;
-           else{ id->width = (Uint32)atol(mdcbufr); prev->XDIM = id->width; }
-           
-           if(id->width == 0) return("RAW  No width specified");
-         MdcPrntScrn("\tImage rows    [%u]? ",prev->YDIM); 
-           if (MdcPutDefault(mdcbufr)) id->height = prev->YDIM;
-           else{ id->height = (Uint32)atol(mdcbufr); prev->YDIM = id->height; }
-           if (id->height == 0) return("RAW  No height specified");
-         MdcPrntScrn("\tPixel data type:\n\n");
-         MdcPrntScrn("\t\t %2d  ->  bit\n",BIT1);
-         MdcPrntScrn("\t\t %2d  ->  Int8 \t\t %2d -> Uint8\n",BIT8_S,BIT8_U);
-         MdcPrntScrn("\t\t %2d  ->  Int16\t\t %2d -> Uint16\n",BIT16_S,BIT16_U);
-         MdcPrntScrn("\t\t %2d  ->  Int32\t\t %2d -> Uint32\n",BIT32_S,BIT32_U);
-#ifdef HAVE_8BYTE_INT
-         MdcPrntScrn("\t\t %2d  ->  Int64\t\t %2d -> Uint64\n",BIT64_S,BIT64_U);
-#endif
-         MdcPrntScrn("\t\t %2d  ->  float\t\t %2d -> double\n",FLT32,FLT64);
-         MdcPrntScrn("\t\t %2d  ->  ascii\n",ASCII);
-         MdcPrntScrn("\t\t %2d  ->  RGB\n\n",COLRGB);
-         MdcPrntScrn("\tYour choice [%hu]? ", prev->PTYPE);
-
-         if (MdcPutDefault(mdcbufr)) id->type = prev->PTYPE;
-         else{ id->type = (Int16)atoi(mdcbufr); prev->PTYPE = id->type; }
-         MdcPrntScrn("\n"); 
-       }else{
-         id->width = prev->XDIM;
-         id->height = prev->YDIM; 
-         id->type  = prev->PTYPE;
-         input->abs_offset[i]= prev->ABSHDR;
-       }
- 
-       switch (id->type) {
-         case  BIT1   : 
-         case  BIT8_S :
-         case  BIT8_U :
-         case  BIT16_S:
-         case  BIT16_U:
-         case  BIT32_S:
-         case  BIT32_U:
-#ifdef HAVE_8BYTE_INT
-         case  BIT64_S:
-         case  BIT64_U:
-#endif
-         case  FLT32  :
-         case  FLT64  : 
-         case  ASCII  : 
-         case  COLRGB : id->bits = MdcType2Bits(id->type); break;
-         default      : return("RAW  Unsupported data type");
-       }
-     }
-
-     fi->endian = MDC_FILE_ENDIAN;
-     fi->dim[0] = 3;
-     fi->dim[3] = fi->number;
-
-     MdcPrintImageLayout(fi,input->gen_offset,input->img_offset,
-                            input->abs_offset,input->REPEAT);
-
-     MdcPrntScrn("\n\tRedo input [no]? "); mdcbufr[0]='n'; AGAIN=MDC_NO;
-      if (!MdcPutDefault(mdcbufr))
-        if (mdcbufr[0]=='y' || mdcbufr[0]=='Y') {
-          AGAIN=MDC_YES;
-          MdcFreeIDs(fi);
-          MdcFree(input->abs_offset);
-        }
-
-  }while ( AGAIN );
+  /* get raw input parameters required to read binary images */
+  err=MdcGetRawInput(fi);
+  if (err != NULL) return(err);
 
   if (MDC_VERBOSE) MdcPrntMesg("RAW  Reading <%s> ...",fi->ifname);
 
-  fseek(fi->ifp,(signed)input->gen_offset,SEEK_SET);
- 
+  fseeko(fi->ifp,input->gen_offset,SEEK_SET);
+
   /* read the images */
   for (i = 0; i<fi->number; i++) {
 
-     if ( i==0  || input->REPEAT)
-       fseek(fi->ifp,(signed)input->img_offset,SEEK_CUR);
-
-     if (input->abs_offset[i] != 0)
-       fseek(fi->ifp,(signed)input->abs_offset[i],SEEK_SET);
+     if (MDC_PROGRESS) MdcProgress(MDC_PROGRESS_INCR,1./(float)fi->number,NULL);
 
      id = &fi->image[i];
+
+     if ( i==0  || input->REPEAT)
+       fseeko(fi->ifp,input->img_offset,SEEK_CUR);
+
+     if (id->load_location != 0)
+       fseeko(fi->ifp,id->load_location,SEEK_SET);
+
      bytes = id->width * id->height * MdcType2Bytes(id->type);
      id->buf = MdcGetImgBuffer(bytes);
      if (id->buf == NULL) {
-       MdcFree(input->abs_offset);
        return("RAW  Bad malloc image buffer");
      }
      if (id->type == ASCII) {
        pix = (double *)id->buf;
        for (p=0; p < (id->width * id->height); p++) {
-          fscanf(fi->ifp,"%le",&pix[p]);
-          if (ferror(fi->ifp)) {
+          r = fscanf(fi->ifp,"%le",&pix[p]);
+          if (r != 1) {
             err=MdcHandleTruncated(fi,i+1,MDC_YES);
             if (err != NULL) {
-              MdcFree(input->abs_offset);
               return(err);
             }
             break;
@@ -324,18 +384,17 @@ char *MdcReadRAW(FILEINFO *fi)
        id->type = FLT64; /* read ascii as double */
      }else{
       if (fread(id->buf,1,bytes,fi->ifp) != bytes) {
-        err=MdcHandleTruncated(fi,i+1,MDC_YES); 
+        err=MdcHandleTruncated(fi,i+1,MDC_YES);
         if (err != NULL) {
-          MdcFree(input->abs_offset);
           return(err);
         }
       }
-     } 
+     }
      if (id->type == BIT1)  {
        MdcMakeBIT8_U(id->buf, fi, i);
        id->type = BIT8_U;
        id->bits = MdcType2Bits(id->type);
-       if (i==0) { fi->type = id->type; fi->bits = id->bits; } 
+       if (i==0) { fi->type = id->type; fi->bits = id->bits; }
      }
 
      if (id->type == COLRGB) fi->map = MDC_MAP_PRESENT; /* color */
@@ -343,8 +402,6 @@ char *MdcReadRAW(FILEINFO *fi)
      if (fi->truncated) break;
   }
 
-  MdcFree(input->abs_offset);
-
   MdcCloseFile(fi->ifp);
 
   if (fi->truncated) return("RAW  Truncated image file");
@@ -365,11 +422,11 @@ char *MdcWriteRAW(FILEINFO *fi)
   if (MDC_FILE_STDOUT == MDC_YES)  MdcPrintFI(fi);
 
   switch (fi->rawconv) {
-   case MDC_FRMT_RAW:   
-       if (XMDC_GUI == MDC_NO) 
+   case MDC_FRMT_RAW:
+       if (XMDC_GUI == MDC_NO)
          MdcDefaultName(fi,MDC_FRMT_RAW,fi->ofname,fi->ifname);
        break;
-   case MDC_FRMT_ASCII: 
+   case MDC_FRMT_ASCII:
        if (XMDC_GUI == MDC_NO)
          MdcDefaultName(fi,MDC_FRMT_ASCII,fi->ofname,fi->ifname);
        break;
@@ -382,7 +439,7 @@ char *MdcWriteRAW(FILEINFO *fi)
          break;
      case MDC_FRMT_ASCII: MdcProgress(MDC_PROGRESS_BEGIN,0.,"Writing ASCII:");
          break;
-    } 
+    }
   }
 
   if (MDC_VERBOSE) MdcPrntMesg("RAW  Writing <%s> ...",fi->ofname);
@@ -404,7 +461,7 @@ char *MdcWriteRAW(FILEINFO *fi)
   /* check some supported things */
   if (fi->type != COLRGB) {
     if (MDC_FORCE_INT != MDC_NO) {
-      /* Sorry, no message.  The user should know ... */ 
+      /* Sorry, no message.  The user should know ... */
     }else if (MDC_QUANTIFY || MDC_CALIBRATE) {
       if (fi->rawconv == MDC_FRMT_RAW) {
         MdcPrntWarn("RAW  Quantification to `float' type");
@@ -426,7 +483,7 @@ char *MdcWriteRAW(FILEINFO *fi)
        }
      }else if (MDC_FORCE_INT != MDC_NO) {    /* int */
        switch (MDC_FORCE_INT) {
-         case BIT8_U : 
+         case BIT8_U :
            new_buf=MdcGetImgBIT8_U(fi,i);
            if (new_buf == NULL) return("RAW  Bad malloc Uint8 buffer");
            break;
@@ -462,7 +519,7 @@ char *MdcWriteRAW(FILEINFO *fi)
        bytes = MdcType2Bytes(FLT32);
        switch (fi->rawconv) {
          case MDC_FRMT_RAW:
-           if (MDC_FILE_ENDIAN != MDC_HOST_ENDIAN) 
+           if (MDC_FILE_ENDIAN != MDC_HOST_ENDIAN)
              MdcMakeImgSwapped(new_buf,fi,i,id->width,id->height,FLT32);
            if (fwrite(new_buf,bytes,size,fi->ofp) != size) {
              MdcFree(new_buf);
@@ -505,7 +562,7 @@ char *MdcWriteRAW(FILEINFO *fi)
   }
 
   MdcCloseFile(fi->ofp);
- 
+
   return NULL;
 
 }
@@ -514,10 +571,12 @@ int MdcCheckPredef(const char *fname)
 {
   FILE *fp;
   char sig[10];
+  int r;
 
   if ((fp = fopen(fname,"rb")) == NULL) return(MDC_NO);
 
-  fread(sig,1,10,fp); MdcCloseFile(fp);
+  r = fread(sig,1,10,fp); MdcCloseFile(fp);
+  if (r != 10) return(MDC_NO);
 
   if ( memcmp(sig,MDC_PREDEFSIG,10) ) return(MDC_NO);
 
@@ -532,21 +591,21 @@ char *MdcReadPredef(const char *fname)
   prev->DIFF = MDC_NO;
   prev->PSWAP = MDC_NO;
   prev->HDRREP = MDC_NO;
- 
+
   if ((fp = fopen(fname,"rb")) == NULL) {
     return("Couldn't open raw predef input file");
   }else{
     MdcGetStrLine(mdcbufr,80,fp); prev->NRIMGS=(Uint32)atoi(mdcbufr);
-    MdcGetStrLine(mdcbufr,80,fp); prev->GENHDR=(Uint32)atoi(mdcbufr);
-    MdcGetStrLine(mdcbufr,80,fp); prev->IMGHDR=(Uint32)atoi(mdcbufr);
+    MdcGetStrLine(mdcbufr,80,fp); prev->GENHDR=(off_t)atoll(mdcbufr);
+    MdcGetStrLine(mdcbufr,80,fp); prev->IMGHDR=(off_t)atoll(mdcbufr);
     MdcGetStrLine(mdcbufr,80,fp); if (mdcbufr[0] == 'y') prev->HDRREP = MDC_YES;
     MdcGetStrLine(mdcbufr,80,fp); if (mdcbufr[0] == 'y') prev->PSWAP = MDC_YES;
     MdcGetStrLine(mdcbufr,80,fp); if (mdcbufr[0] == 'y') { } /*no DIFF allowed*/
-    MdcGetStrLine(mdcbufr,80,fp); prev->ABSHDR=(Uint32)atoi(mdcbufr);
+    MdcGetStrLine(mdcbufr,80,fp); prev->ABSHDR=(off_t)atoll(mdcbufr);
     MdcGetStrLine(mdcbufr,80,fp); prev->XDIM=(Uint32)atoi(mdcbufr);
     MdcGetStrLine(mdcbufr,80,fp); prev->YDIM=(Uint32)atoi(mdcbufr);
     MdcGetStrLine(mdcbufr,80,fp); prev->PTYPE=(Int16)atoi(mdcbufr);
-    /* MdcGetStrLine(mdcbufr,80,fp); */  /* redo */
+    /* MdcGetStrLine(mdcbufr,80,fp); */  /* redo for next file */
   }
 
   if (ferror(fp)) {
@@ -568,14 +627,14 @@ char *MdcWritePredef(const char *fname)
 
   if (MdcKeepFile(fname))
     return("Raw predef input file already exists!!");
- 
+
   if ((fp = fopen(fname,"w")) == NULL) {
     return("Couldn't open writeable raw predef input file");
   }else{
     fprintf(fp,"%s - BEGIN #\n#\n",MDC_PREDEFSIG); /* MDC_PREDEFSIG - BEGIN */
     fprintf(fp,"# Total number of images?\n%u\n",prev->NRIMGS);
-    fprintf(fp,"# General header offset (bytes)?\n%u\n",prev->GENHDR);
-    fprintf(fp,"# Image   header offset (bytes)?\n%u\n",prev->IMGHDR);
+    fprintf(fp,"# General header offset (bytes)?\n%jd\n",(intmax_t)prev->GENHDR);
+    fprintf(fp,"# Image   header offset (bytes)?\n%jd\n",(intmax_t)prev->IMGHDR);
     fprintf(fp,"# Repeated image header?\n");
     if (prev->HDRREP == MDC_YES) {
       fprintf(fp,"yes\n");
@@ -589,11 +648,11 @@ char *MdcWritePredef(const char *fname)
       fprintf(fp,"no\n");
     }
     fprintf(fp,"# Identical images?\nyes\n");
-    fprintf(fp,"# Absolute offset in bytes?\n%u\n",prev->ABSHDR);
+    fprintf(fp,"# Absolute offset in bytes?\n%jd\n",(intmax_t)prev->ABSHDR);
     fprintf(fp,"# Image columns?\n%u\n",prev->XDIM);
     fprintf(fp,"# Image rows?\n%u\n",prev->YDIM);
     fprintf(fp,"# Pixel data type?\n%hu\n",prev->PTYPE);
-    fprintf(fp,"# Redo input?\nno\n");
+    fprintf(fp,"# Redo input for next file?\nno\n");
     fprintf(fp,"#\n%s - END #\n",MDC_PREDEFSIG);
   }
 
@@ -606,4 +665,3 @@ char *MdcWritePredef(const char *fname)
   return(NULL);
 }
 
-
