@@ -8,11 +8,11 @@
  * project      : (X)MedCon by Erik Nolf                                   *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id$
+/*
  */
 
 /*
-   Copyright (C) 1997-2019 by Erik Nolf
+   Copyright (C) 1997-2026 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -45,15 +45,13 @@ Uint8 XMDC_FILE_TYPE=XMDC_NORMAL;
 
 Uint8 XMDC_IMAGE_BORDER = 1; /* border between images in viewer window */
 
-GdkColor Red;
-GdkColor Green;
-GdkColor Blue;
-GdkColor Yellow;
+Uint8 XMDC_MENUBAR_PACK = GTK_PACK_DIRECTION_LTR; /* _LTR = Left-to-Right 
+                                                     _RTL = Right-to-Left
+                                                     _TTB = Top-to-Bottom
+                                                     _BTT = Bottom-to-Top */
 
 GdkCursor *handcursor;
-GdkCursor *fleurcursor;
-
-GdkFont *sfixed;
+GdkCursor *zoomcursor;
 
 MyMainStruct my;
 OptionsMedConStruct sOptionsMedCon;
@@ -68,7 +66,7 @@ PagesSelectionStruct   sPagesSelection;
 ColGbcCorrectStruct    sGbc;
 EditFileInfoStruct     sEditFI;
 
-char   labelindex[25];
+char   labelindex[50];
 char   labeltimes[50];
 Uint32 write_counter=0;
 char   xmdcstr[MDC_2KB_OFFSET];
