@@ -8,11 +8,11 @@
  * project      : (X)MedCon by Erik Nolf                                   *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id$
+/*
  */
 
 /*
-   Copyright (C) 1997-2019 by Erik Nolf
+   Copyright (C) 1997-2026 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -66,12 +66,15 @@
 #define XMDC_ZOOM_OUT       -(XMDC_ZOOM_FACTOR)  /* decr */
 #define XMDC_ZOOM_NONE         0
 
+#define XMDC_RESIZE_FIFTH     -5   /* 1:5 */
 #define XMDC_RESIZE_FOURTH    -4   /* 1:4 */
 #define XMDC_RESIZE_THIRD     -3   /* 1:3 */
 #define XMDC_RESIZE_HALF      -2   /* 1:2 */
 #define XMDC_RESIZE_ORIGINAL   1   /* 1:1 */
 #define XMDC_RESIZE_DOUBLE     2   /* 2:1 */
 #define XMDC_RESIZE_TRIPLE     3   /* 3:1 */
+#define XMDC_RESIZE_QUAD       4   /* 4:1 */
+#define XMDC_RESIZE_QUINT      5   /* 5:1 */
 
 #define XMDC_PAGES_FRAME_BY_FRAME 0                   /* frame by frame */
 #define XMDC_PAGES_SLICE_BY_SLICE 1                   /* slice by slice */
@@ -81,15 +84,6 @@
 
 #define XMDC_MAX_LOADABLE_LUTS  999      /* maximum external LUTs available */
 
-#ifdef _WIN32
-#define MDC_USE_SIGNAL_BLOCKER 1
-#endif
-
-typedef struct SignalBlocker_t{
-  guint id;
-  gboolean blocked;
-}SignalBlocker;
-
 typedef struct OptionsMedConStruct_t {
         GtkWidget *PixPositives;
         GtkWidget *PixNegatives;
@@ -150,19 +144,19 @@ typedef struct OptionsMedConStruct_t {
 
 typedef struct MyMainStruct_t {
     GtkWidget *mainwindow;
+    GtkWidget *menubar;
     GtkWidget *viewwindow;
     GtkWidget *viewbox;
     GtkWidget *pagemenu;
     GtkWidget *imgsbox;
-    GtkWidget *imgstable;
+    GtkWidget *imgsgrid;
     GtkWidget *cmapbox;
     GtkWidget **image;
     GtkWidget *cmap;
     GdkPixbuf **im, *imcmap;
     GdkInterpType interp;
-    GdkRgbDither dither;
-    SignalBlocker *sblkr;
     gint cmap_w, cmap_h;
+    int screen_height, screen_width;
 
     FILEINFO *fi;
     Uint32 curpage, prevpage;
@@ -197,8 +191,6 @@ typedef struct LabelSelectionStruct_t {
    gint CurState;
    gint CurColor;
    gint CurStyle;
-   GdkGC *gc;
-   GdkColor  *color;
    GtkWidget *On;
    GtkWidget *Off;
    GtkWidget *Red;
@@ -212,15 +204,11 @@ typedef struct LabelSelectionStruct_t {
 
 
 typedef struct RenderSelectionStruct_t {
-   GdkRgbDither  Dither;
    GdkInterpType Interp;
    GtkWidget *InterpNearest;
    GtkWidget *InterpTiles;
    GtkWidget *InterpBilinear;
    GtkWidget *InterpHyper;
-   GtkWidget *DitherNone;
-   GtkWidget *DitherNormal;
-   GtkWidget *DitherMax;
 }RenderSelectionStruct;
 
 typedef struct ExtractSelectionStruct_t {
@@ -254,11 +242,14 @@ typedef struct RawReadSelectionStruct_t {
 typedef struct ResizeSelectionStruct_t {
    Int8 CurType;
    GtkWidget *Original;
+   GtkWidget *Fifth;
    GtkWidget *Fourth;
    GtkWidget *Third;
    GtkWidget *Half;
    GtkWidget *Double;
    GtkWidget *Triple;
+   GtkWidget *Quad;
+   GtkWidget *Quint;
 }ResizeSelectionStruct;
 
 typedef struct PagesSelectionStruct_t{
@@ -269,7 +260,7 @@ typedef struct PagesSelectionStruct_t{
 }PagesSelectionStruct;
 
 typedef struct SliderValueStruct_t {
-  GtkObject  *adj;
+  GtkAdjustment *adj;
   GtkWidget  *range;
   int        *value;
 }SliderValueStruct;
@@ -281,10 +272,10 @@ typedef struct ColorModifier_t{
 
 typedef struct ColGbcCorrectStruct_t {
   GtkWidget *area;
-  GdkPixmap *brightness_pmap, *brightness_mask;
-  GdkPixmap *contrast_pmap, *contrast_mask;
-  GdkPixmap *gamma_pmap, *gamma_mask;
-  GdkPixbuf *im;
+  GdkPixbuf *image;
+  GdkPixbuf *brightness_icon;
+  GdkPixbuf *contrast_icon;
+  GdkPixbuf *gamma_icon;
   ColorModifier mod;
   Uint32 i, nr, w, h, rw, rh;
   Int16 t;
@@ -317,19 +308,13 @@ extern Uint8 XMDC_FILE_OPEN;
 extern Uint8 XMDC_FILE_TYPE;
 
 extern Uint8 XMDC_IMAGE_BORDER;
+extern Uint8 XMDC_MENUBAR_PACK;
 extern Uint8 XMDC_CMAP_PLACE;
 
 extern Uint8 XMDC_DOBAR;
 
-extern GdkColor Red;
-extern GdkColor Green;
-extern GdkColor Blue;
-extern GdkColor Yellow;
-
 extern GdkCursor *handcursor;
-extern GdkCursor *fleurcursor;
-
-extern GdkFont *sfixed;
+extern GdkCursor *zoomcursor;
 
 extern MyMainStruct            my;
 extern OptionsMedConStruct     sOptionsMedCon;
@@ -344,7 +329,7 @@ extern PagesSelectionStruct    sPagesSelection;
 extern ColGbcCorrectStruct     sGbc;
 extern EditFileInfoStruct      sEditFI;
 
-extern char labelindex[25];
+extern char labelindex[50];
 extern char labeltimes[50];
 extern Uint32 write_counter;
 
