@@ -8,11 +8,11 @@
  * project      : (X)MedCon by Erik Nolf                                   *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id$
+/*
  */
 
 /*
-   Copyright (C) 1997-2019 by Erik Nolf
+   Copyright (C) 1997-2026 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -34,21 +34,23 @@
 /****************************************************************************
                             F U N C T I O N S
 ****************************************************************************/
-void XMdcFileSelOpenCallbackOk(GtkWidget *w, GtkWidget *fs);
+void XMdcFileSelOpenOk(GtkWidget *fs);
 void XMdcFileSelOpen(GtkWidget *widget, guint otype);
-void XMdcFileSelSaveCreateFormatMenu(GtkWidget *fs, guint format);
-void XMdcFileSelSaveCreateDefaultName(GtkWidget *fs);
-void XMdcFileSelSaveCallbackFormatMenu(GtkWidget *fs, guint *selected_format);
-void XMdcFileSelSaveCallbackAlias(GtkObject *fs, char *filename);
-void XMdcFileSelSaveCallbackDefault(GtkObject *fs, char *filename);
-void XMdcFileSelSaveCallbackOk(GtkWidget *w, GtkWidget *fs);
-void XMdcFileSelSaveCallbackCancel(GtkWidget *w, GtkWidget *fs);
+void XMdcFileSelSaveSetDefaultName(GtkWidget *fs);
+GtkWidget *XMdcFileSelSaveCreateFormatMenu(GtkWidget *fs, guint format);
+GtkWidget *XMdcFileSelSaveCreateBtnAlias(GtkWidget *fs);
+GtkWidget *XMdcFileSelSaveCreateBtnDefault(GtkWidget *fs);
+void XMdcFileSelSaveCallbackFormatMenu(GtkWidget *widget, gpointer data);
+void XMdcFileSelSaveCallbackAlias(GtkWidget *fs, char *filename);
+void XMdcFileSelSaveCallbackDefault(GtkWidget *fs, char *filename);
+void XMdcFileSelSaveCancel(GtkWidget *fs);
+void XMdcFileSelSaveOk(GtkWidget *fs);
 void XMdcFileSelSave(GtkWidget *widget, guint format);
-void XMdcLutSelOpenCallbackOk(GtkWidget *w, GtkWidget *fs);
-void XMdcLutSelOpen(GtkWidget *w, gpointer data);
-void XMdcRawPredefSelSaveCallbackOk(GtkWidget *widget, GtkWidget *fs);
+void XMdcLutSelOpenOk(GtkWidget *fs);
+void XMdcLutSelOpen(void);
+void XMdcRawPredefSelSaveOk(GtkWidget *fs);
 void XMdcRawPredefSelSave(GtkWidget *widget, gpointer data);
-void XMdcRawPredefSelOpenCallbackOk(GtkWidget *w, GtkWidget *fs);
+void XMdcRawPredefSelOpenOk(GtkWidget *fs);
 void XMdcRawPredefSelOpen(GtkWidget *widget, gpointer data);
 
 #endif
