@@ -10,11 +10,11 @@
  * Functions    : main()      - Main XMedCon routine                       *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id$
+/*
  */
 
 /*
-   Copyright (C) 1997-2019 by Erik Nolf
+   Copyright (C) 1997-2026 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -38,10 +38,10 @@
 #include "m-depend.h"
 
 #include <stdio.h>
-#ifdef HAVE_STRING_H
+#ifdef LIBMDC_HAVE_STRING_H
 #include <string.h>
 #endif
-#ifdef HAVE_STRINGS_H
+#ifdef LIBMDC_HAVE_STRINGS_H
 #ifndef _WIN32
 #include <strings.h>
 #endif
@@ -54,8 +54,6 @@
 ****************************************************************************/
 int main(int argc, char *argv[])
 {
-    GtkWidget *main_vbox;
-    GtkWidget *menubar;
     FILEINFO fi;
 
     my.fi = &fi;
@@ -84,27 +82,19 @@ int main(int argc, char *argv[])
     sExtractSelection.input->style = MDC_INPUT_NORM_STYLE;
     sResizeSelection.CurType = XMDC_RESIZE_ORIGINAL;
     sPagesSelection.CurType = XMDC_PAGES_FRAME_BY_FRAME;
-    sRenderSelection.Dither = GDK_RGB_DITHER_MAX;
-    sRenderSelection.Interp = GDK_INTERP_HYPER; /*GDK_INTERP_BILINEAR;*/
+    sRenderSelection.Interp = GDK_INTERP_BILINEAR; /* GDK_INTERP_HYPER seems deprecated */
     sGbc.mod.gamma = 256;
     sGbc.mod.brightness = 256;
     sGbc.mod.contrast = 256;
     XMdcSetGbcCorrection(&sGbc.mod);
-    sGbc.im = NULL;
+    sGbc.image = NULL;
     MdcInitRawPrevInput();
 
-#ifndef GTKONE
     /* preserve POSIX locale: decimal = point */
     gtk_disable_setlocale();
-#endif
 
-    /* initialize the GTK/GDK_RGB engines */
+    /* initialize the GTK engine */
     gtk_init(&argc, &argv);
-    gdk_rgb_init();
-
-    /* prevent unwanted Gdk-ERROR messages */
-    gtk_widget_set_default_colormap(gdk_rgb_get_cmap());
-    gtk_widget_set_default_visual(gdk_rgb_get_visual());
 
     /* initialize XMedCon global struct */
     my.viewwindow = NULL; XMdcStructsReset();
@@ -163,35 +153,25 @@ int main(int argc, char *argv[])
         sColormapSelection.CurMap = MDC_MAP_LOADED;
     }
 
-#ifdef _WIN32
     XMdcCreateLogConsole();
-#endif
 
-    XMdcConfigureXMedcon();
+    XMdcConfigureCssTheme();
 
     my.mainwindow = gtk_window_new(GTK_WINDOW_TOPLEVEL);
-    gtk_signal_connect(GTK_OBJECT(my.mainwindow), "destroy",
-                       GTK_SIGNAL_FUNC(XMdcMedconQuit),
+    g_signal_connect(my.mainwindow, "destroy",
+                       G_CALLBACK(XMdcMedconQuit),
                        "WM destroy");
     gtk_window_set_title(GTK_WINDOW(my.mainwindow), MDC_PRGR);
-    gtk_window_set_policy(GTK_WINDOW(my.mainwindow),FALSE,TRUE,FALSE);
+    gtk_window_set_resizable(GTK_WINDOW(my.mainwindow), TRUE);
 
-    main_vbox = gtk_vbox_new(FALSE, 1);
-    gtk_container_set_border_width(GTK_CONTAINER(main_vbox), 1);
-    gtk_container_add(GTK_CONTAINER(my.mainwindow), main_vbox);
-    gtk_widget_show(main_vbox);
+    XMdcAttachMainMenu(my.mainwindow);
 
-    XMdcMenusGetMain(my.mainwindow, &menubar);
+    gtk_widget_show_all(my.mainwindow);
 
-    gtk_box_pack_start(GTK_BOX(main_vbox), menubar, FALSE, TRUE, 0);
-    gtk_widget_show(menubar);
+    /* get some preferred stuff */
+    XMdcMakeMyCursors(); /* cursors for over pixmaps images */
 
-    gtk_widget_show(my.mainwindow);
-
-    /* get some prefered stuff */
-    XMdcMakeMyCursors(); /* cursors for over pixmaps images  */
-    XMdcMakeMyColors();  /* colors  for the  pixmaps labels  */
-    XMdcMakeMyFonts();   /* fixed fonts                      */
+    XMdcGetScreenWorkingArea(); /* get screen working area  */
 
     /* display file on argument */
     if (mdc_arg_total[MDC_FILES] == 1) XMdcDisplayFile(mdc_arg_files[0]);
